@@ -34,4 +34,8 @@ class SubstitutionSpanStrategy implements SpanStrategy {
 	public void endSpan(DocumentBuilder builder) {
 		builder.endSpan();
 	}
+
+	SpanType getType() {
+		return type;
+	}
 }
