@@ -12,6 +12,7 @@
  *      Sascha Scholz (SAP) - improvements
  *      Francois Chouinard (Ericsson) - Bug 414253 Add support for Gerrit Dashboard
  *      Jacques Bouthillier (Ericsson) - Bug 414253 Add support for Gerrit Dashboard
+ *      Jacques Bouthillier (Ericsson) - Bug 426505 Add Starred functionality
  *********************************************************************/
 package org.eclipse.mylyn.internal.gerrit.core;
 
@@ -153,7 +154,7 @@ public class GerritConnector extends ReviewsConnector {
 
 	@Override
 	public String getLabel() {
-		return "Gerrit Code Review (supports 2.6.1 and later)";
+		return Messages.GerritConnector_Label;
 	}
 
 	@Override
@@ -229,7 +230,7 @@ public class GerritConnector extends ReviewsConnector {
 	public IStatus performQuery(TaskRepository repository, IRepositoryQuery query, TaskDataCollector resultCollector,
 			ISynchronizationSession session, IProgressMonitor monitor) {
 		try {
-			monitor.beginTask("Executing query", IProgressMonitor.UNKNOWN);
+			monitor.beginTask(Messages.GerritConnector_Executing_query, IProgressMonitor.UNKNOWN);
 			GerritClient client = getClient(repository);
 			client.refreshConfigOnce(monitor);
 
@@ -461,4 +462,19 @@ public class GerritConnector extends ReviewsConnector {
 	public static boolean isClosed(String status) {
 		return EnumSet.of(ReviewStatus.MERGED, ReviewStatus.ABANDONED).contains(ReviewStatus.get(status));
 	}
+
+	public void setStarred(TaskRepository taskRepository, String taskID, boolean starred,
+			IProgressMonitor progressMonitor) throws CoreException {
+		GerritClient client = getClient(taskRepository);
+		try {
+			client.setStarred(taskID, starred, progressMonitor);
+		} catch (GerritException e) {
+			throw toCoreException(e);
+		}
+	}
+
+	private CoreException toCoreException(GerritException e) {
+		return new CoreException(new Status(IStatus.ERROR, GerritCorePlugin.PLUGIN_ID,
+				"Unable to set the starred flag, the following Status is received", e)); //$NON-NLS-1$
+	}
 }
