@@ -13,6 +13,7 @@
  *      Christian Trutz - improvements
  *      Francois Chouinard - Added "LABELS" option on selected queries
  *      Jacques Bouthillier - Bug 414253 Add support for Gerrit Dashboard
+ *      Jacques Bouthillier (Ericsson) - Bug 426505 Add Starred functionality
  *********************************************************************/
 package org.eclipse.mylyn.internal.gerrit.core.client;
 
@@ -94,6 +95,7 @@ import com.google.gerrit.common.data.GerritConfig;
 import com.google.gerrit.common.data.PatchSetDetail;
 import com.google.gerrit.common.data.ReviewerResult;
 import com.google.gerrit.common.data.SingleListChangeInfo;
+import com.google.gerrit.common.data.ToggleStarRequest;
 import com.google.gerrit.reviewdb.Account;
 import com.google.gerrit.reviewdb.AccountDiffPreference;
 import com.google.gerrit.reviewdb.AccountDiffPreference.Whitespace;
@@ -408,11 +410,11 @@ public class GerritClient extends ReviewsClient {
 		});
 		if (patchScript.isBinary()) {
 			if (patchScript.getChangeType() != ChangeType.ADDED) {
-				String keyBaseEncoded = encode(key.toString() + "^1"); //$NON-NLS-1$
+				String keyBaseEncoded = encode(leftId + "," + key.getFileName() + "^0"); //$NON-NLS-1$ //$NON-NLS-2$
 				patchScript.setBinaryA(fetchBinaryContent("/cat/" + keyBaseEncoded, monitor)); //$NON-NLS-1$
 			}
 			if (patchScript.getChangeType() != ChangeType.DELETED) {
-				String keyTargetEncoded = encode(key.toString() + "^0"); //$NON-NLS-1$
+				String keyTargetEncoded = encode(rightId + "," + key.getFileName() + "^0"); //$NON-NLS-1$ //$NON-NLS-2$
 				patchScript.setBinaryB(fetchBinaryContent("/cat/" + keyTargetEncoded, monitor)); //$NON-NLS-1$
 			}
 		}
@@ -423,15 +425,26 @@ public class GerritClient extends ReviewsClient {
 		final TypeToken<Byte[]> byteArrayType = new TypeToken<Byte[]>() {
 		};
 		byte[] bin = executeGetRestRequest(url, byteArrayType.getType(), monitor);
-		if (isVersion27OrLater(monitor)) {
-			return bin;
-		} else if (isVersion26OrLater(monitor)) {
+		if (isZippedContent(bin)) {
 			return unzip(bin);
+		} else {
+			return bin;
 		}
-		return null;
 	}
 
-	private static byte[] unzip(byte[] zip) throws GerritException {
+	/**
+	 * Checks for the 4 byte header that identifies a ZIP file
+	 * 
+	 * @noreference This method is not intended to be referenced by clients.
+	 */
+	public static boolean isZippedContent(byte[] bin) {
+		return bin != null && bin.length > 4 && bin[0] == 'P' && bin[1] == 'K' && bin[2] == 3 && bin[3] == 4;
+	}
+
+	/**
+	 * @noreference This method is not intended to be referenced by clients.
+	 */
+	public static byte[] unzip(byte[] zip) throws GerritException {
 		ZipInputStream zis = new ZipInputStream(new ByteArrayInputStream(zip));
 		try {
 			zis.getNextEntry(); // expecting a single entry
@@ -755,6 +768,11 @@ public class GerritClient extends ReviewsClient {
 		return GerritVersion.isVersion27OrLater(version);
 	}
 
+	private boolean isVersion28OrLater(IProgressMonitor monitor) throws GerritException {
+		Version version = getCachedVersion(monitor);
+		return GerritVersion.isVersion28OrLater(version);
+	}
+
 	/**
 	 * Returns watched changes of the currently logged in user
 	 */
@@ -1172,6 +1190,34 @@ public class GerritClient extends ReviewsClient {
 		});
 	}
 
+	private <T> T executePutRestRequest(final String url, final Object input, final Type resultType,
+			final ErrorHandler handler, IProgressMonitor monitor) throws GerritException {
+		return execute(monitor, new Operation<T>() {
+			@Override
+			public void execute(IProgressMonitor monitor) throws GerritException {
+				try {
+					setResult(client.<T> putRestRequest(url, input, resultType, handler, monitor));
+				} catch (IOException e) {
+					throw new GerritException(e);
+				}
+			}
+		});
+	}
+
+	private <T> T executeDeleteRestRequest(final String url, final Object input, final Type resultType,
+			final ErrorHandler handler, IProgressMonitor monitor) throws GerritException {
+		return execute(monitor, new Operation<T>() {
+			@Override
+			public void execute(IProgressMonitor monitor) throws GerritException {
+				try {
+					setResult(client.<T> deleteRestRequest(url, input, resultType, handler, monitor));
+				} catch (IOException e) {
+					throw new GerritException(e);
+				}
+			}
+		});
+	}
+
 	private <T> T executeOnce(IProgressMonitor monitor, Operation<T> operation) throws GerritException {
 		operation.execute(monitor);
 		if (operation.getException() instanceof GerritException) {
@@ -1277,4 +1323,43 @@ public class GerritClient extends ReviewsClient {
 			throw new GerritException(e);
 		}
 	}
+
+	public VoidResult setStarred(final String reviewId, final boolean starred, IProgressMonitor monitor)
+			throws GerritException {
+		final Change.Id id = new Change.Id(id(reviewId));
+		final ToggleStarRequest req = new ToggleStarRequest();
+		req.toggle(id, starred);
+		if (isVersion28OrLater(monitor)) {
+			final String uri = "/a/accounts/self/starred.changes/" + id.get(); //$NON-NLS-1$
+
+			return execute(monitor, new Operation<VoidResult>() {
+				@Override
+				public void execute(IProgressMonitor monitor) throws GerritException {
+
+					if (starred) {
+						executePutRestRequest(uri, req, ToggleStarRequest.class, createErrorHandler(), monitor);
+					} else {
+						executeDeleteRestRequest(uri, req, ToggleStarRequest.class, createErrorHandler(), monitor);
+					}
+				}
+			});
+
+		} else {
+			return execute(monitor, new Operation<VoidResult>() {
+				@Override
+				public void execute(IProgressMonitor monitor) throws GerritException {
+					getChangeListService(monitor).toggleStars(req, this);
+				}
+			});
+		}
+	}
+
+	private ErrorHandler createErrorHandler() {
+		return new ErrorHandler() {
+			@Override
+			public void handleError(HttpMethodBase method) throws GerritException {
+				throw new GerritException(method.getStatusLine().getReasonPhrase());
+			}
+		};
+	}
 }
