@@ -15,6 +15,7 @@ import static org.eclipse.mylyn.gerrit.tests.core.client.rest.IsEmpty.empty;
 import static org.eclipse.mylyn.internal.gerrit.core.client.rest.ApprovalUtil.CRVW;
 import static org.eclipse.mylyn.internal.gerrit.core.client.rest.ApprovalUtil.VRIF;
 import static org.eclipse.mylyn.internal.gerrit.core.client.rest.ApprovalUtil.toNameWithDash;
+import static org.eclipse.mylyn.internal.gerrit.core.remote.TestRemoteObserverConsumer.retrieveForRemoteKey;
 import static org.hamcrest.Matchers.endsWith;
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.is;
@@ -57,7 +58,6 @@ import org.eclipse.mylyn.reviews.core.model.IReviewerEntry;
 import org.eclipse.mylyn.reviews.core.model.IUser;
 import org.eclipse.mylyn.reviews.core.model.RequirementStatus;
 import org.eclipse.mylyn.reviews.core.model.ReviewStatus;
-import org.eclipse.mylyn.reviews.core.spi.remote.emf.RemoteEmfConsumer;
 import org.junit.Test;
 
 import com.google.gerrit.common.data.ApprovalDetail;
@@ -84,7 +84,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		reviewHarness.client.publishComments(reviewHarness.shortId, 1, message2,
 				Collections.<ApprovalCategoryValue.Id> emptySet(), null);
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 		List<IComment> comments = getReview().getComments();
 		int offset = getCommentOffset();
 		assertThat(comments.size(), is(offset + 2));
@@ -114,14 +114,11 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 
 	@Test
 	public void testNewChange() throws Exception {
-		CommitCommand command2 = reviewHarness.git.commit()
-				.setAmend(true)
-				.setAll(true)
-				.setMessage("Test Change " + reviewHarness.testIdent + " [2]\n\nChange-Id: " + reviewHarness.changeId);
-		reviewHarness.gerritHarness.project().addFile("testFile2.txt");
-		reviewHarness.gerritHarness.project().commitAndPush(command2);
+		CommitCommand command2 = reviewHarness.createCommitCommand();
+		reviewHarness.addFile("testFile2.txt");
+		reviewHarness.commitAndPush(command2);
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 		List<IReviewItemSet> items = getReview().getSets();
 		assertThat(items.size(), is(2));
 		IReviewItemSet patchSet2 = items.get(1);
@@ -157,7 +154,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 				new HashSet<ApprovalCategoryValue.Id>(Collections.singleton(CRVW.getValue((short) 1).getId())),
 				new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 		assertThat(getReview().getReviewerApprovals().size(), is(1));
 		Entry<IUser, IReviewerEntry> reviewerEntry = getReview().getReviewerApprovals().entrySet().iterator().next();
 		Map<IApprovalType, Integer> reviewerApprovals = reviewerEntry.getValue().getApprovals();
@@ -188,21 +185,15 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 	@Test
 	public void testDependencies() throws Exception {
 		String changeIdDep1 = "I" + StringUtils.rightPad(System.currentTimeMillis() + "", 40, "a");
-		CommitCommand commandDep1 = reviewHarness.git.commit()
-				.setAll(true)
-				.setMessage("Test Change Dependent 1 " + reviewHarness.testIdent + "\n\nChange-Id: " + changeIdDep1);
-		reviewHarness.gerritHarness.project().addFile("testFile1.txt", "test 2");
-		CommitResult resultDep1 = reviewHarness.gerritHarness.project().commitAndPush(commandDep1);
+		CommitCommand commandDep1 = reviewHarness.createCommitCommand(changeIdDep1);
+		reviewHarness.addFile("testFile1.txt", "test 2");
+		CommitResult resultDep1 = reviewHarness.commitAndPush(commandDep1);
 		String resultIdDep1 = StringUtils.trimToEmpty(StringUtils.substringAfterLast(resultDep1.push.getMessages(), "/"));
 		assertThat("Bad Push: " + resultDep1.push.getMessages(), resultIdDep1.length(), greaterThan(0));
 
-		TestRemoteObserver<IRepository, IReview, String, Date> reviewListenerDep1 = new TestRemoteObserver<IRepository, IReview, String, Date>(
-				reviewHarness.provider.getReviewFactory());
-		RemoteEmfConsumer<IRepository, IReview, String, GerritChange, String, Date> consumerDep1 = reviewHarness.provider.getReviewFactory()
-				.getConsumerForRemoteKey(reviewHarness.getRepository(), resultIdDep1);
-		consumerDep1.addObserver(reviewListenerDep1);
-		consumerDep1.retrieve(false);
-		reviewListenerDep1.waitForResponse(1, 1);
+		TestRemoteObserverConsumer<IRepository, IReview, String, GerritChange, String, Date> consumerDep1 //
+		= retrieveForRemoteKey(reviewHarness.provider.getReviewFactory(), reviewHarness.getRepository(), resultIdDep1,
+				true);
 		IReview reviewDep1 = consumerDep1.getModelObject();
 
 		assertThat(reviewDep1.getParents().size(), is(1));
@@ -213,7 +204,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		assertThat(parentChange.getModificationDate().getTime(), is(getReview().getModificationDate().getTime()));
 
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 		assertThat(getReview().getChildren().size(), is(1));
 		IChange childChange = getReview().getChildren().get(0);
 		//Not expected to be same instance
@@ -229,7 +220,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		ChangeDetail changeDetail = reviewHarness.client.abandon(reviewHarness.shortId, 1, message1,
 				new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 
 		assertThat(changeDetail, notNullValue());
 		assertThat(changeDetail.getChange().getStatus(), is(Status.ABANDONED));
@@ -254,12 +245,12 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		String message1 = "abandon, time: " + System.currentTimeMillis();
 		reviewHarness.client.abandon(reviewHarness.shortId, 1, message1, new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 		String message2 = "restore, time: " + System.currentTimeMillis();
 
 		reviewHarness.client.restore(reviewHarness.shortId, 1, message2, new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(3, 3);
+		reviewHarness.listener.waitForResponse();
 
 		assertThat(getReview().getState(), is(ReviewStatus.NEW));
 		List<IComment> comments = getReview().getComments();
@@ -310,7 +301,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		ReviewerResult reviewerResult = reviewHarness.client.addReviewers(reviewHarness.shortId,
 				Collections.<String> emptyList(), new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 
 		assertThat(reviewerResult, notNullValue());
 		assertThat(reviewerResult.getErrors().isEmpty(), is(true));
@@ -325,7 +316,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		ReviewerResult reviewerResult = reviewHarness.client.addReviewers(reviewHarness.shortId, reviewers,
 				new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 
 		assertThat(reviewerResult, notNullValue());
 		assertThat(reviewerResult.getErrors().size(), is(1));
@@ -342,7 +333,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		ReviewerResult reviewerResult = reviewHarness.client.addReviewers(reviewHarness.shortId, reviewers,
 				new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 
 		assertReviewerResult(reviewerResult, "foo");
 	}
@@ -355,7 +346,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		ReviewerResult reviewerResult = reviewHarness.client.addReviewers(reviewHarness.shortId, reviewers,
 				new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 
 		assertReviewerResult(reviewerResult, null);
 	}
@@ -367,7 +358,7 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		ReviewerResult reviewerResult = reviewHarness.client.addReviewers(reviewHarness.shortId, reviewers,
 				new NullProgressMonitor());
 		reviewHarness.consumer.retrieve(false);
-		reviewHarness.listener.waitForResponse(2, 2);
+		reviewHarness.listener.waitForResponse();
 
 		assertReviewerResult(reviewerResult, null);
 	}
@@ -476,6 +467,27 @@ public class GerritReviewRemoteFactoryTest extends GerritRemoteTest {
 		assertThat(crvwAllowed.getMax(), is(1));
 	}
 
+	@Test
+	public void testSetStarred() throws Exception {
+
+		int reviewId = Integer.parseInt(reviewHarness.shortId);
+		//Set the Starred to a review
+		reviewHarness.client.setStarred(reviewHarness.shortId, true, new NullProgressMonitor());
+
+		ChangeDetailX changeDetail = reviewHarness.client.getChangeDetail(reviewId, new NullProgressMonitor());
+		assertEquals(true, changeDetail.isStarred());
+
+		//Test if already the Starred was set, should react the same way
+		reviewHarness.client.setStarred(reviewHarness.shortId, true, new NullProgressMonitor());
+		changeDetail = reviewHarness.client.getChangeDetail(reviewId, new NullProgressMonitor());
+		assertEquals(true, changeDetail.isStarred());
+
+		reviewHarness.client.setStarred(reviewHarness.shortId, false, new NullProgressMonitor());
+		changeDetail = reviewHarness.client.getChangeDetail(reviewId, new NullProgressMonitor());
+		assertEquals(false, changeDetail.isStarred());
+
+	}
+
 	private int getCommentOffset() throws GerritException {
 		// Version 2.8 adds a comment for each uploaded patch set
 		return isVersion28OrLater() ? 1 : 0;
