@@ -29,6 +29,7 @@ import org.eclipse.jface.viewers.StyledString.Styler;
 import org.eclipse.mylyn.commons.core.DateUtil;
 import org.eclipse.mylyn.commons.ui.CommonImages;
 import org.eclipse.mylyn.commons.workbench.CommonImageManger;
+import org.eclipse.mylyn.internal.reviews.ui.Messages;
 import org.eclipse.mylyn.internal.reviews.ui.ReviewsImages;
 import org.eclipse.mylyn.reviews.core.model.IComment;
 import org.eclipse.mylyn.reviews.core.model.ICommentContainer;
@@ -64,9 +65,9 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 
 	static final int MAXIMUM_COMMENT_LENGTH = 300;
 
-	static final SimpleDateFormat COMMENT_DATE_FORMAT = new SimpleDateFormat("yyyy.MM.dd HH:mm a");
+	static final SimpleDateFormat COMMENT_DATE_FORMAT = new SimpleDateFormat("yyyy.MM.dd HH:mm a"); //$NON-NLS-1$
 
-	static final SimpleDateFormat EXTENDED_DATE_FORMAT = new SimpleDateFormat("EEE, d MMM yyyy HH:mm:ss Z");
+	static final SimpleDateFormat EXTENDED_DATE_FORMAT = new SimpleDateFormat("EEE, d MMM yyyy HH:mm:ss Z"); //$NON-NLS-1$
 
 	public final static Styler AUTHOR_STYLE = new Styler() {
 		@Override
@@ -101,7 +102,8 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 		}
 	};
 
-	public static final TableColumnProvider ITEMS_COLUMN = new TableColumnProvider("Item", 80, 800, true) {
+	public static final TableColumnProvider ITEMS_COLUMN = new TableColumnProvider(Messages.ReviewsLabelProvider_Item,
+			80, 800, true) {
 
 		CommonImageManger imageManager = new CommonImageManger();
 
@@ -163,7 +165,7 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 				return org.eclipse.mylyn.internal.reviews.ui.Messages.Reviews_GeneralCommentsText;
 			}
 			if (element instanceof RetrievingContentsNode) {
-				return org.eclipse.mylyn.internal.reviews.ui.Messages.Reviews_RetrievingContents;
+				return org.eclipse.mylyn.reviews.ui.spi.editor.Messages.Reviews_RetrievingContents;
 			}
 			if (element instanceof Collection) {
 				Collection<?> collection = (Collection<?>) element;
@@ -173,7 +175,7 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 			}
 			if (element instanceof IReview) {
 				IReview review = (IReview) element;
-				return "Change " + review.getId();
+				return NLS.bind(Messages.ReviewsLabelProvider_Change_X, review.getId());
 			}
 			if (element instanceof IFileVersion) {
 				IFileVersion version = (IFileVersion) element;
@@ -183,7 +185,7 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 			}
 			if (element instanceof IFileItem) {
 				//Note, we want platform independent separator here.
-				return StringUtils.substringAfterLast(((IFileItem) element).getName(), "/");
+				return StringUtils.substringAfterLast(((IFileItem) element).getName(), "/"); //$NON-NLS-1$
 			}
 			if (element instanceof IReviewItem) {
 				return ((IReviewItem) element).getName();
@@ -199,17 +201,18 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 				if (!StringUtils.isEmpty(displayName)) {
 					return displayName;
 				}
-				return "Unknown";
+				return Messages.ReviewsLabelProvider_Unknown;
 			}
 			if (element instanceof Date) {
-				return DateUtil.getRelativeDuration(System.currentTimeMillis() - ((Date) element).getTime()) + " ago";
+				return NLS.bind(Messages.ReviewsLabelProvider_X_ago,
+						DateUtil.getRelativeDuration(System.currentTimeMillis() - ((Date) element).getTime()));
 			}
 			if (element instanceof ILineLocation) {
 				int min = ((ILineLocation) element).getRangeMin();
 				int max = ((ILineLocation) element).getRangeMax();
-				String text = min + "";
+				String text = Integer.toString(min);
 				if (min != max) {
-					text += "-" + max;
+					text += "-" + max; //$NON-NLS-1$
 				}
 				return text;
 			}
@@ -237,12 +240,12 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 			if (element instanceof IComment) {
 				IComment comment = (IComment) element;
 				String desc = comment.getDescription();
-				desc = StringUtils.replace(desc, "\r\n", "\n");
-				String[] lines = desc.split("\n");
+				desc = StringUtils.replace(desc, "\r\n", "\n"); //$NON-NLS-1$ //$NON-NLS-2$
+				String[] lines = desc.split("\n"); //$NON-NLS-1$
 				List<String> seperated = new ArrayList<String>();
 				for (String line : lines) {
-					String newLine = "";
-					String[] splitByWholeSeparator = StringUtils.splitByWholeSeparator(line, " ");
+					String newLine = ""; //$NON-NLS-1$
+					String[] splitByWholeSeparator = StringUtils.splitByWholeSeparator(line, " "); //$NON-NLS-1$
 					int count = 0;
 					for (String word : splitByWholeSeparator) {
 						count += word.length();
@@ -252,34 +255,37 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 							count = word.length();
 						} else {
 							if (count > word.length()) {
-								newLine += " ";
+								newLine += " "; //$NON-NLS-1$
 							}
 							newLine += word;
 						}
 					}
 					seperated.add(newLine);
 				}
-				return StringUtils.join(seperated, "\n");
+				return StringUtils.join(seperated, "\n"); //$NON-NLS-1$
 			}
 			if (element instanceof IFileItem) {
 				IFileItem fileItem = (IFileItem) element;
 				IFileVersion base = fileItem.getBase();
 				IFileVersion target = fileItem.getTarget();
 				if (target.getPath() != null && base.getPath() == null) {
-					return target.getPath() + " Revision: " + target.getDescription();
+					return NLS.bind(Messages.ReviewsLabelProvider_X_Revision_Y, target.getPath(),
+							target.getDescription());
 				} else if (target.getPath() == null && base.getPath() != null) {
-					return base.getPath() + " Revision: " + target.getDescription();
+					return NLS.bind(Messages.ReviewsLabelProvider_X_Revision_Y, base.getPath(), target.getDescription());
 				} else if (!target.getPath().equals(base.getPath())) {
-					return target.getPath() + "\n renamed from: " + base.getPath() + " " + target.getDescription();
+					return NLS.bind(Messages.ReviewsLabelProvider_X_renamed_from_Y_Z, new Object[] { target.getPath(),
+							base.getPath(), target.getDescription() });
 				} else {
-					return target.getPath() + " Revision: " + target.getDescription();
+					return NLS.bind(Messages.ReviewsLabelProvider_X_Revision_Y, target.getPath(),
+							target.getDescription());
 				}
 			}
 			if (element instanceof IUser) {
 				IUser user = (IUser) element;
 				String text = user.getDisplayName();
 				if (!StringUtils.isEmpty(user.getEmail())) {
-					text += " <" + user.getEmail() + ">";
+					text += NLS.bind(Messages.ReviewsLabelProvider_Bracket_X_bracket, user.getEmail());
 				}
 				return text;
 			}
@@ -295,8 +301,8 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 		};
 	};
 
-	public static final TableColumnProvider ARTIFACT_COLUMN = new AdaptingTableColumnProvider(ITEMS_COLUMN, "Artifact",
-			50, 400, false) {
+	public static final TableColumnProvider ARTIFACT_COLUMN = new AdaptingTableColumnProvider(ITEMS_COLUMN,
+			Messages.ReviewsLabelProvider_Artifact, 50, 400, false) {
 
 		@Override
 		public Object adapt(Object element) {
@@ -331,8 +337,8 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 		};
 	};
 
-	public static final TableColumnProvider COMMENTS_COLUMN = new AdaptingTableColumnProvider(ITEMS_COLUMN, "Comment",
-			50, 400, true) {
+	public static final TableColumnProvider COMMENTS_COLUMN = new AdaptingTableColumnProvider(ITEMS_COLUMN,
+			Messages.ReviewsLabelProvider_Comment, 50, 400, true) {
 		@Override
 		public Object adapt(Object element) {
 			if (element instanceof IComment) {
@@ -352,8 +358,8 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 		};
 	};
 
-	public static final TableColumnProvider AUTHORS_COLUMN = new AdaptingTableColumnProvider(ITEMS_COLUMN, "Author",
-			10, 120, false) {
+	public static final TableColumnProvider AUTHORS_COLUMN = new AdaptingTableColumnProvider(ITEMS_COLUMN,
+			Messages.ReviewsLabelProvider_Author, 10, 120, false) {
 
 		@Override
 		public Object adapt(Object element) {
@@ -373,8 +379,8 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 		}
 	};
 
-	public static final TableColumnProvider DATE_COLUMN = new AdaptingTableColumnProvider(ITEMS_COLUMN, "Last Change",
-			10, 120, false) {
+	public static final TableColumnProvider DATE_COLUMN = new AdaptingTableColumnProvider(ITEMS_COLUMN,
+			Messages.ReviewsLabelProvider_Last_Change, 10, 120, false) {
 
 		@Override
 		public Object adapt(Object element) {
@@ -395,7 +401,8 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 		};
 	};
 
-	public static final TableColumnProvider SINGLE_COLUMN = new TableColumnProvider("Items", 10, 120, false) {
+	public static final TableColumnProvider SINGLE_COLUMN = new TableColumnProvider(
+			Messages.ReviewsLabelProvider_Items, 10, 120, false) {
 
 		@Override
 		public Image getImage(Object element) {
@@ -415,7 +422,7 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 			}
 			if (element instanceof IReview) {
 				IReview review = (IReview) element;
-				return "Change " + review.getId();
+				return NLS.bind(Messages.ReviewsLabelProvider_Change_X, review.getId());
 			}
 			if (element instanceof IFileItem) {
 				IFileItem file = (IFileItem) element;
@@ -440,9 +447,9 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 			if (element instanceof ILineLocation) {
 				int min = ((ILineLocation) element).getRangeMin();
 				int max = ((ILineLocation) element).getRangeMax();
-				String text = min + "";
+				String text = min + ""; //$NON-NLS-1$
 				if (min != max) {
-					text += "-" + max;
+					text += "-" + max; //$NON-NLS-1$
 				}
 				return text;
 			}
@@ -458,20 +465,21 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 					IComment comment = (IComment) element;
 					String commentText = text;
 					int textLength = 0;
-					String authorText = "";
+					String authorText = ""; //$NON-NLS-1$
 					if (comment.getAuthor() != null) {
 						authorText = getText(comment.getAuthor());
 						textLength += authorText.length();
 					}
 					int descSpaceRemaining = (MAXIMUM_COMMENT_LENGTH - textLength);
 					if (commentText.length() > descSpaceRemaining + 3) { //Account for ellipses
-						commentText = commentText.substring(0, descSpaceRemaining - 3) + "..."; //$NON-NLS-1$
+						commentText = NLS.bind(Messages.ReviewsLabelProvider_X_dot_dot_dot,
+								commentText.substring(0, descSpaceRemaining - 3));
 					}
 					commentText = StringUtils.rightPad(commentText, MAXIMUM_COMMENT_LENGTH - textLength);
 
-					styledString.append(authorText + " ", AUTHOR_STYLE);
-					styledString.append(commentText + " ", COMMENT_STYLE);
-					styledString.append(getText(comment.getCreationDate()) + " ", COMMENT_DATE_STYLE);
+					styledString.append(authorText + " ", AUTHOR_STYLE); //$NON-NLS-1$
+					styledString.append(commentText + " ", COMMENT_STYLE); //$NON-NLS-1$
+					styledString.append(getText(comment.getCreationDate()) + " ", COMMENT_DATE_STYLE); //$NON-NLS-1$
 				} else {
 					styledString.append(text);
 				}
@@ -481,7 +489,7 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 				addCommentContainerStatsStyle(element, styledString);
 				if (element instanceof IFileItem) {
 					IReviewItem item = (IReviewItem) element;
-					styledString.append("  " + item.getName(), StyledString.QUALIFIER_STYLER);
+					styledString.append("  " + item.getName(), StyledString.QUALIFIER_STYLER); //$NON-NLS-1$
 				}
 			} else {
 				styledString.append(element.toString());
@@ -594,15 +602,15 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 			for (ILocation location : comment.getLocations()) {
 				locationStrings[index++] = ITEMS_COLUMN.getText(location);
 			}
-			String locationString = StringUtils.join(locationStrings, ", ");
-			styledString.append(" " + locationString, LINE_NUMBER_STYLE);
+			String locationString = StringUtils.join(locationStrings, ", "); //$NON-NLS-1$
+			styledString.append(" " + locationString, LINE_NUMBER_STYLE); //$NON-NLS-1$
 		}
 	}
 
 	public static void addFilePathStyle(Object element, StyledString styledString) {
 		if (element instanceof IFileItem) {
 			IReviewItem item = (IReviewItem) element;
-			styledString.append("  " + item.getName(), StyledString.QUALIFIER_STYLER);
+			styledString.append("  " + item.getName(), StyledString.QUALIFIER_STYLER); //$NON-NLS-1$
 		}
 	}
 
@@ -616,12 +624,12 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 
 	public static String getIndexText(IComment comment) {
 		long index = comment.getIndex();
-		return index < Long.MAX_VALUE ? index + "" : "";
+		return index < Long.MAX_VALUE ? Long.toString(index) : ""; //$NON-NLS-1$
 	}
 
 	public static String getStatsText(ICommentContainer container) {
 		if (container instanceof IReviewItemSet && ((IReviewItemSet) container).getItems().size() == 0) {
-			return "  [?]";
+			return Messages.ReviewsLabelProvider_Question_mark;
 		}
 		List<? extends IComment> comments;
 		if (container instanceof IReview) {
@@ -637,13 +645,13 @@ public abstract class ReviewsLabelProvider extends TableStyledLabelProvider {
 			}
 		}
 		commentCount -= draftCount;
-		String statsText = "";
+		String statsText = ""; //$NON-NLS-1$
 		if (commentCount > 0 && draftCount > 0) {
-			statsText = NLS.bind("  [{0} comments, {1} drafts]", commentCount, draftCount);
+			statsText = NLS.bind(Messages.ReviewsLabelProvider_X_comments_Y_drafts, commentCount, draftCount);
 		} else if (commentCount > 0) {
-			statsText = NLS.bind("  [{0} comments]", commentCount);
+			statsText = NLS.bind(Messages.ReviewsLabelProvider_X_comments, commentCount);
 		} else if (draftCount > 0) {
-			statsText = NLS.bind("  [{0} drafts]", draftCount);
+			statsText = NLS.bind(Messages.ReviewsLabelProvider_X_drafts, draftCount);
 		}
 		return statsText;
 	}
