@@ -24,7 +24,7 @@ public class TckFixture extends AbstractTestFixture {
 		return this;
 	}
 
-	public TaskRepository repository() {
+	public TaskRepository createRepository() {
 		return new TaskRepository(getConnectorKind(), getRepositoryUrl());
 	}
 
