@@ -28,6 +28,7 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.mylyn.bugzilla.tests.support.BugzillaFixture;
+import org.eclipse.mylyn.bugzilla.tests.support.BugzillaTestSupportUtil;
 import org.eclipse.mylyn.commons.net.AuthenticationCredentials;
 import org.eclipse.mylyn.commons.net.AuthenticationType;
 import org.eclipse.mylyn.commons.sdk.util.CommonTestUtil.PrivilegeLevel;
@@ -937,6 +938,8 @@ public class BugzillaRepositoryConnectorTest extends AbstractBugzillaTest {
 	}
 
 	public void testAuthenticationCredentials() throws Exception {
+		// use the client's repository when setting credentials below
+		repository = client.getTaskRepository();
 		TaskData data = BugzillaFixture.current().createTask(PrivilegeLevel.USER, null, null);
 		assertNotNull(data);
 		ITask task = generateLocalTaskAndDownload(data.getTaskId());
@@ -957,7 +960,7 @@ public class BugzillaRepositoryConnectorTest extends AbstractBugzillaTest {
 			AttachmentUtil.postContext(connector, repository, task, "test", attribute, new NullProgressMonitor());
 		} catch (CoreException e) {
 			assertEquals(SynchronizationState.SYNCHRONIZED, task.getSynchronizationState());
-			assertTrue(e.getStatus().getMessage().indexOf("invalid username or password") != -1);
+			assertTrue(BugzillaTestSupportUtil.isInvalidLogon(e));
 			return;
 		} finally {
 			repository.setCredentials(AuthenticationType.REPOSITORY, oldCreds, false);
