@@ -326,7 +326,7 @@ public abstract class AbstractRepositoryConnector {
 	 * @since 3.0
 	 */
 	@NonNull
-	public ITaskMapping getTaskMapping(TaskData taskData) {
+	public ITaskMapping getTaskMapping(@NonNull TaskData taskData) {
 		return new TaskMapper(taskData);
 	}
 
@@ -376,6 +376,23 @@ public abstract class AbstractRepositoryConnector {
 		return null;
 	}
 
+	/**
+	 * Returns a browsable URL for <code>element</code>.
+	 * <p>
+	 * Returns <code>null</code> by default. Clients may override.
+	 * 
+	 * @param repository
+	 *            the repository for <code>element</code>
+	 * @param element
+	 *            the element to return the url for
+	 * @return null, if no corresponding URL is available for <code>element</code>; the URL otherwise
+	 * @since 3.12
+	 */
+	@Nullable
+	public URL getBrowserUrl(@NonNull TaskRepository repository, @NonNull IRepositoryElement element) {
+		return null;
+	}
+
 	/**
 	 * Returns <code>true</code>, if the state in <code>taskData</code> is different than the state stored in
 	 * <code>task</code>.
@@ -629,7 +646,8 @@ public abstract class AbstractRepositoryConnector {
 	 *             thrown in case the operation fails
 	 * @since 3.11
 	 */
-	public RepositoryInfo validateRepository(TaskRepository repository, IProgressMonitor monitor) throws CoreException {
+	@NonNull
+	public RepositoryInfo validateRepository(@NonNull TaskRepository repository, @Nullable IProgressMonitor monitor) throws CoreException {
 		throw new UnsupportedOperationException();
 	}
 
@@ -642,7 +660,7 @@ public abstract class AbstractRepositoryConnector {
 	 *            the repository
 	 * @since 3.11
 	 */
-	public void applyDefaultCategory(TaskRepository repository) {
+	public void applyDefaultCategory(@NonNull TaskRepository repository) {
 		repository.setCategory(TaskRepository.CATEGORY_BUGS);
 	}
 }
