@@ -15,31 +15,24 @@ package org.eclipse.mylyn.tasks.core;
 
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.net.MalformedURLException;
-import java.net.URL;
 import java.util.Date;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
 import java.util.Map;
 import java.util.Set;
 import java.util.TimeZone;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.eclipse.core.runtime.Assert;
-import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
-import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.PlatformObject;
-import org.eclipse.core.runtime.Status;
-import org.eclipse.equinox.security.storage.EncodingUtils;
-import org.eclipse.equinox.security.storage.ISecurePreferences;
-import org.eclipse.equinox.security.storage.SecurePreferencesFactory;
-import org.eclipse.equinox.security.storage.StorageException;
-import org.eclipse.mylyn.commons.core.StatusHandler;
 import org.eclipse.mylyn.commons.net.AuthenticationCredentials;
 import org.eclipse.mylyn.commons.net.AuthenticationType;
+import org.eclipse.mylyn.commons.repositories.core.ILocationService;
+import org.eclipse.mylyn.commons.repositories.core.auth.ICredentialsStore;
+import org.eclipse.mylyn.internal.commons.repositories.core.InMemoryCredentialsStore;
+import org.eclipse.mylyn.internal.commons.repositories.core.LocationService;
 import org.eclipse.mylyn.internal.tasks.core.IRepositoryConstants;
-import org.eclipse.mylyn.internal.tasks.core.ITasksCoreConstants;
 import org.eclipse.mylyn.internal.tasks.core.RepositoryPerson;
 
 /**
@@ -53,16 +46,14 @@ import org.eclipse.mylyn.internal.tasks.core.RepositoryPerson;
  * <li>The solution we have come up with thus far is not to interpret the date as a DATE object but rather simply use
  * the date string given to us by the repository itself.</li>
  * </ul>
- * 
+ *
  * @author Mik Kersten
  * @author Rob Elves
  * @author Eugene Kuleshov
  * @author Steffen Pingel
  * @since 2.0
  */
-@SuppressWarnings("deprecation")
 public final class TaskRepository extends PlatformObject {
-
 	public static final String DEFAULT_CHARACTER_ENCODING = "UTF-8"; //$NON-NLS-1$
 
 	private static final String USERNAME = ".username"; //$NON-NLS-1$
@@ -115,12 +106,6 @@ public final class TaskRepository extends PlatformObject {
 
 	public static final String NO_VERSION_SPECIFIED = "unknown"; //$NON-NLS-1$
 
-	private static final String AUTH_SCHEME = "Basic"; //$NON-NLS-1$
-
-	private static final String AUTH_REALM = ""; //$NON-NLS-1$
-
-	private static final URL DEFAULT_URL;
-
 	private static final String PROPERTY_CONFIG_TIMESTAMP = "org.eclipse.mylyn.tasklist.repositories.configuration.timestamp"; //$NON-NLS-1$
 
 	public static final String PROXY_USEDEFAULT = "org.eclipse.mylyn.tasklist.repositories.proxy.usedefault"; //$NON-NLS-1$
@@ -149,7 +134,7 @@ public final class TaskRepository extends PlatformObject {
 
 	/**
 	 * Category for repositories that manage tasks.
-	 * 
+	 *
 	 * @see #setCategory(String)
 	 * @since 3.9
 	 */
@@ -157,7 +142,7 @@ public final class TaskRepository extends PlatformObject {
 
 	/**
 	 * Category for repositories that manage bugs.
-	 * 
+	 *
 	 * @see #setCategory(String)
 	 * @since 3.9
 	 */
@@ -165,7 +150,7 @@ public final class TaskRepository extends PlatformObject {
 
 	/**
 	 * Category for repositories that manage builds.
-	 * 
+	 *
 	 * @see #setCategory(String)
 	 * @since 3.9
 	 */
@@ -173,33 +158,16 @@ public final class TaskRepository extends PlatformObject {
 
 	/**
 	 * Category for repositories that manage reviews.
-	 * 
+	 *
 	 * @see #setCategory(String)
 	 * @since 3.9
 	 */
 	public static final String CATEGORY_REVIEW = "org.eclipse.mylyn.category.review"; //$NON-NLS-1$
 
-	// HACK: Lock used to work around race condition in
-	// Platform.add/get/flushAuthorizationInfo()
-	private static final Object LOCK = new Object();
-
 	private final Set<PropertyChangeListener> propertyChangeListeners = new HashSet<PropertyChangeListener>();
 
-	// HACK: private credentials for headless operation
-	private static Map<String, Map<String, String>> credentials = new HashMap<String, Map<String, String>>();
-
 	private static String CREATED_FROM_TEMPLATE = "org.eclipse.mylyn.tasklist.repositories.template"; //$NON-NLS-1$
 
-	static {
-		URL url = null;
-		try {
-			url = new URL("http://eclipse.org/mylyn"); //$NON-NLS-1$
-		} catch (Exception ex) {
-			// TODO ?
-		}
-		DEFAULT_URL = url;
-	}
-
 	private static String getKeyPrefix(AuthenticationType type) {
 		switch (type) {
 		case HTTP:
@@ -224,7 +192,7 @@ public final class TaskRepository extends PlatformObject {
 	 * Stores properties that are not persisted. Note that this map is currently cleared when flushCredentials() is
 	 * invoked.
 	 */
-	private final Map<String, String> transientProperties = new HashMap<String, String>();
+	private final Map<String, String> transientProperties = new ConcurrentHashMap<String, String>();
 
 	/*
 	 * TODO: should be externalized and added to extension point, see bug 183606
@@ -235,6 +203,8 @@ public final class TaskRepository extends PlatformObject {
 
 	private boolean shouldPersistCredentials = true;
 
+	private final ILocationService service = LocationService.getDefault();
+
 	public TaskRepository(String connectorKind, String repositoryUrl) {
 		this(connectorKind, repositoryUrl, NO_VERSION_SPECIFIED);
 	}
@@ -270,91 +240,30 @@ public final class TaskRepository extends PlatformObject {
 		setProperty(IRepositoryConstants.PROPERTY_ENCODING, encoding);
 		setProperty(IRepositoryConstants.PROPERTY_TIMEZONE, timeZoneId);
 		// use platform proxy by default (headless will need to set this to false)
-		this.setProperty(TaskRepository.PROXY_USEDEFAULT, new Boolean(true).toString());
+		setBooleanProperty(TaskRepository.PROXY_USEDEFAULT, true);
 
 		// for backwards compatibility to versions prior to 2.2
-		this.setProperty(AUTH_REPOSITORY + SAVE_PASSWORD, String.valueOf(true));
-		this.setProperty(AUTH_HTTP + SAVE_PASSWORD, String.valueOf(true));
-		this.setProperty(AUTH_PROXY + SAVE_PASSWORD, String.valueOf(true));
+		setBooleanProperty(AUTH_REPOSITORY + SAVE_PASSWORD, true);
+		setBooleanProperty(AUTH_HTTP + SAVE_PASSWORD, true);
+		setBooleanProperty(AUTH_PROXY + SAVE_PASSWORD, true);
 	}
 
-	private ISecurePreferences getSecurePreferences() {
-		ISecurePreferences securePreferences = SecurePreferencesFactory.getDefault()
-				.node(ITasksCoreConstants.ID_PLUGIN);
-		securePreferences = securePreferences.node(EncodingUtils.encodeSlashes(getRepositoryUrl()));
-		return securePreferences;
+	private ICredentialsStore getCredentialsStore() {
+		if (!shouldPersistCredentials()) {
+			// use a different ID so that we use a different in memory store than that used as a cache by the secure store
+			return InMemoryCredentialsStore.getStore("headless::" + getRepositoryUrl()); //$NON-NLS-1$
+		}
+		return getService().getCredentialsStore(getRepositoryUrl());
 	}
 
 	private void addAuthInfo(String username, String password, String userProperty, String passwordProperty) {
-		if (Platform.isRunning() && shouldPersistCredentials()) {
-			if (useSecureStorage()) {
-				try {
-					ISecurePreferences securePreferences = getSecurePreferences();
-					if (userProperty.equals(getKeyPrefix(AuthenticationType.REPOSITORY) + USERNAME)) {
-						this.setProperty(userProperty, username);
-					} else {
-						securePreferences.put(userProperty, username, false);
-					}
-					securePreferences.put(passwordProperty, password, true);
-				} catch (StorageException e) {
-					StatusHandler.log(new Status(IStatus.ERROR, ITasksCoreConstants.ID_PLUGIN,
-							"Could not store authorization credentials", e)); //$NON-NLS-1$
-				}
-			} else {
-				synchronized (LOCK) {
-					Map<String, String> map = getAuthInfo();
-					if (map == null) {
-						map = new HashMap<String, String>();
-					}
-					try {
-						try {
-							map.put(userProperty, username);
-							map.put(passwordProperty, password);
-							Platform.addAuthorizationInfo(new URL(getRepositoryUrl()), AUTH_REALM, AUTH_SCHEME, map);
-						} catch (MalformedURLException ex) {
-							Platform.addAuthorizationInfo(DEFAULT_URL, getRepositoryUrl(), AUTH_SCHEME, map);
-						}
-					} catch (CoreException e) {
-						StatusHandler.log(new Status(IStatus.ERROR, ITasksCoreConstants.ID_PLUGIN,
-								"Could not set authorization credentials", e)); //$NON-NLS-1$
-					}
-				}
-			}
+		ICredentialsStore credentialsStore = getCredentialsStore();
+		if (userProperty.equals(getKeyPrefix(AuthenticationType.REPOSITORY) + USERNAME)) {
+			this.setProperty(userProperty, username);
 		} else {
-			synchronized (LOCK) {
-				Map<String, String> headlessCreds = credentials.get(getRepositoryUrl());
-				if (headlessCreds == null) {
-					headlessCreds = new HashMap<String, String>();
-					credentials.put(getRepositoryUrl(), headlessCreds);
-				}
-				headlessCreds.put(userProperty, username);
-				headlessCreds.put(passwordProperty, password);
-			}
-		}
-	}
-
-	@SuppressWarnings({ "unchecked" })
-	private Map<String, String> getAuthInfo() {
-		synchronized (LOCK) {
-			if (Platform.isRunning()) {
-				try {
-					return Platform.getAuthorizationInfo(new URL(getRepositoryUrl()), AUTH_REALM, AUTH_SCHEME);
-				} catch (MalformedURLException ex) {
-					return Platform.getAuthorizationInfo(DEFAULT_URL, getRepositoryUrl(), AUTH_SCHEME);
-				} catch (Exception e) {
-					StatusHandler.log(new Status(IStatus.ERROR, ITasksCoreConstants.ID_PLUGIN,
-							"Could not retrieve authorization credentials", e)); //$NON-NLS-1$
-				}
-			} else {
-				Map<String, String> headlessCreds = credentials.get(getRepositoryUrl());
-				if (headlessCreds == null) {
-					headlessCreds = new HashMap<String, String>();
-					credentials.put(getRepositoryUrl(), headlessCreds);
-				}
-				return headlessCreds;
-			}
-			return null;
+			credentialsStore.put(userProperty, username, false);
 		}
+		credentialsStore.put(passwordProperty, password, true);
 	}
 
 	/**
@@ -383,109 +292,23 @@ public final class TaskRepository extends PlatformObject {
 		setProperty(getKeyPrefix(AuthenticationType.PROXY) + ENABLED, null);
 		setProperty(getKeyPrefix(AuthenticationType.REPOSITORY) + ENABLED, null);
 
-		synchronized (this) {
-			transientProperties.clear();
-			isCachedUserName = false;
-		}
+		transientProperties.clear();
+		isCachedUserName = false;
 
-		synchronized (LOCK) {
-			if (Platform.isRunning() && shouldPersistCredentials()) {
-				if (useSecureStorage()) {
-					if (Platform.isRunning()) {
-						ISecurePreferences securePreferences = getSecurePreferences();
-						securePreferences.removeNode();
-						this.setProperty(AuthenticationType.REPOSITORY + USERNAME, ""); //$NON-NLS-1$
-					} else {
-						Map<String, String> headlessCreds = credentials.get(getRepositoryUrl());
-						if (headlessCreds != null) {
-							headlessCreds.clear();
-						}
-					}
-				} else {
-					try {
-						try {
-							Platform.flushAuthorizationInfo(new URL(getRepositoryUrl()), AUTH_REALM, AUTH_SCHEME);
-						} catch (MalformedURLException ex) {
-							Platform.flushAuthorizationInfo(DEFAULT_URL, getRepositoryUrl(), AUTH_SCHEME);
-						}
-					} catch (CoreException e) {
-						// FIXME propagate exception?
-						StatusHandler.log(new Status(IStatus.ERROR, ITasksCoreConstants.ID_PLUGIN,
-								"Could not flush authorization credentials", e)); //$NON-NLS-1$
-					}
-				}
-			} else {
-				Map<String, String> headlessCreds = credentials.get(getRepositoryUrl());
-				if (headlessCreds != null) {
-					headlessCreds.clear();
-				}
-			}
-		}
+		getCredentialsStore().clear();
+		this.setProperty(AuthenticationType.REPOSITORY + USERNAME, ""); //$NON-NLS-1$
 	}
 
-	private boolean useSecureStorage() {
-		String useSecure = getProperty(ITasksCoreConstants.PROPERTY_USE_SECURE_STORAGE);
-		if (useSecure != null) {
-			return "true".equals(useSecure); //$NON-NLS-1$
-		}
-		return false;
-	}
-
-	@SuppressWarnings("unchecked")
 	private String getAuthInfo(String property) {
-		if (Platform.isRunning() && shouldPersistCredentials()) {
-			if (useSecureStorage()) {
-				String propertyValue = null;
-				if (property.equals(getKeyPrefix(AuthenticationType.REPOSITORY) + USERNAME)) {
-					propertyValue = this.getProperty(property);
-				} else {
-					try {
-						ISecurePreferences securePreferences = getSecurePreferences();
-						propertyValue = securePreferences.get(property, null);
-					} catch (StorageException e) {
-						StatusHandler.log(new Status(IStatus.ERROR, ITasksCoreConstants.ID_PLUGIN,
-								"Could not retrieve authorization credentials", e)); //$NON-NLS-1$
-					}
-				}
-				return propertyValue;
-			} else {
-				synchronized (LOCK) {
-					try {
-						Map<String, String> map = Platform.getAuthorizationInfo(new URL(getRepositoryUrl()),
-								AUTH_REALM, AUTH_SCHEME);
-						if (map != null) {
-							String propertyValue = map.get(property);
-							return propertyValue;
-						}
-					} catch (MalformedURLException ex) {
-						Map<String, String> map = Platform.getAuthorizationInfo(DEFAULT_URL, getRepositoryUrl(),
-								AUTH_SCHEME);
-						if (map != null) {
-							String propertyValue = map.get(property);
-							return propertyValue;
-						}
-					} catch (Exception e) {
-						StatusHandler.log(new Status(IStatus.ERROR, ITasksCoreConstants.ID_PLUGIN,
-								"Could not retrieve authorization credentials", e)); //$NON-NLS-1$
-					}
-					return null;
-				}
-			}
-		} else {
-			synchronized (LOCK) {
-				Map<String, String> headlessCreds = credentials.get(getRepositoryUrl());
-				if (headlessCreds == null) {
-					headlessCreds = new HashMap<String, String>();
-					credentials.put(getRepositoryUrl(), headlessCreds);
-				}
-				return headlessCreds.get(property);
-			}
+		if (property.equals(getKeyPrefix(AuthenticationType.REPOSITORY) + USERNAME)) {
+			return getProperty(property);
 		}
+		return getCredentialsStore().get(property, null);
 	}
 
 	/**
 	 * Returns {@code} if credentials persisted in the platform keystore.
-	 * 
+	 *
 	 * @since 3.10
 	 * @see #setShouldPersistCredentials(boolean)
 	 */
@@ -498,7 +321,7 @@ public final class TaskRepository extends PlatformObject {
 	 * will not be persisted in the platform keystore.
 	 * <p>
 	 * This flag does not have any effect if not running in an OSGi environment.
-	 * 
+	 *
 	 * @since 3.10
 	 * @see #shouldPersistCredentials()
 	 */
@@ -513,7 +336,7 @@ public final class TaskRepository extends PlatformObject {
 
 	/**
 	 * Get the last refresh date as initialized {@link Date} object, null if not set<br />
-	 * 
+	 *
 	 * @return {@link Date} configuration date, null if not set
 	 */
 	public Date getConfigurationDate() {
@@ -542,22 +365,19 @@ public final class TaskRepository extends PlatformObject {
 
 	/**
 	 * Returns the credentials for an authentication type.
-	 * 
+	 *
 	 * @param authType
 	 *            the type of authentication
 	 * @return null, if no credentials are set for <code>authType</code>
 	 * @since 3.0
 	 */
-	public synchronized AuthenticationCredentials getCredentials(AuthenticationType authType) {
+	public AuthenticationCredentials getCredentials(AuthenticationType authType) {
 		String key = getKeyPrefix(authType);
-
-		String enabled = getProperty(key + ENABLED);
-		if (enabled == null || "true".equals(enabled)) { //$NON-NLS-1$
+		if (getBooleanProperty(key + ENABLED)) {
 			String userName = getAuthInfo(key + USERNAME);
 			String password;
 
-			String savePassword = getProperty(key + SAVE_PASSWORD);
-			if (savePassword != null && "true".equals(savePassword)) { //$NON-NLS-1$
+			if (getBooleanProperty(key + SAVE_PASSWORD)) {
 				password = getAuthInfo(key + PASSWORD);
 			} else {
 				password = transientProperties.get(key + PASSWORD);
@@ -570,11 +390,6 @@ public final class TaskRepository extends PlatformObject {
 				password = ""; //$NON-NLS-1$
 			}
 
-			if (enabled == null && userName.length() == 0) {
-				// API30: legacy support for versions prior to 2.2 that did not set the enable flag, remove for 3.0
-				return null;
-			}
-
 			return new AuthenticationCredentials(userName, password);
 		} else {
 			return null;
@@ -621,6 +436,10 @@ public final class TaskRepository extends PlatformObject {
 		return this.properties.get(name);
 	}
 
+	private boolean getBooleanProperty(String name) {
+		return Boolean.parseBoolean(getProperty(name));
+	}
+
 	/**
 	 * @deprecated use {@link #getCredentials(AuthenticationType)} instead
 	 */
@@ -683,12 +502,8 @@ public final class TaskRepository extends PlatformObject {
 	public String getUserName() {
 		// NOTE: if anonymous, user name is "" string so we won't go to keyring
 		if (!isCachedUserName) {
-			if (useSecureStorage()) {
-				// do not open secure store for username to avoid prompting user for password during initialization 
-				cachedUserName = getProperty(getKeyPrefix(AuthenticationType.REPOSITORY) + USERNAME);
-			} else {
-				cachedUserName = getUserName(AuthenticationType.REPOSITORY);
-			}
+			// do not open secure store for username to avoid prompting user for password during initialization
+			cachedUserName = getProperty(getKeyPrefix(AuthenticationType.REPOSITORY) + USERNAME);
 			isCachedUserName = true;
 		}
 		return cachedUserName;
@@ -769,12 +584,12 @@ public final class TaskRepository extends PlatformObject {
 	public void setCharacterEncoding(String characterEncoding) {
 		properties.put(IRepositoryConstants.PROPERTY_ENCODING, characterEncoding == null
 				? DEFAULT_CHARACTER_ENCODING
-				: characterEncoding);
+						: characterEncoding);
 	}
 
 	/**
 	 * Set the Configuration date to the {@link Date} indicated.
-	 * 
+	 *
 	 * @param configuration
 	 *            date {@link {@link Date}
 	 */
@@ -786,7 +601,7 @@ public final class TaskRepository extends PlatformObject {
 
 	/**
 	 * Sets the credentials for <code>authType</code>.
-	 * 
+	 *
 	 * @param authType
 	 *            the type of authentication
 	 * @param credentials
@@ -796,23 +611,22 @@ public final class TaskRepository extends PlatformObject {
 	 *            memory only
 	 * @since 3.0
 	 */
-	public synchronized void setCredentials(AuthenticationType authType, AuthenticationCredentials credentials,
-			boolean savePassword) {
+	public void setCredentials(AuthenticationType authType, AuthenticationCredentials credentials, boolean savePassword) {
 		String key = getKeyPrefix(authType);
 
-		setProperty(key + SAVE_PASSWORD, String.valueOf(savePassword));
+		setBooleanProperty(key + SAVE_PASSWORD, savePassword);
 
 		if (credentials == null) {
-			setProperty(key + ENABLED, String.valueOf(false));
+			setBooleanProperty(key + ENABLED, false);
 			transientProperties.remove(key + PASSWORD);
-			addAuthInfo("", "", key + USERNAME, key + PASSWORD); //$NON-NLS-1$ //$NON-NLS-2$
+			addAuthInfo(null, null, key + USERNAME, key + PASSWORD);
 		} else {
-			setProperty(key + ENABLED, String.valueOf(true));
+			setBooleanProperty(key + ENABLED, true);
 			if (savePassword) {
 				addAuthInfo(credentials.getUserName(), credentials.getPassword(), key + USERNAME, key + PASSWORD);
 				transientProperties.remove(key + PASSWORD);
 			} else {
-				addAuthInfo(credentials.getUserName(), "", key + USERNAME, key + PASSWORD); //$NON-NLS-1$
+				addAuthInfo(credentials.getUserName(), null, key + USERNAME, key + PASSWORD);
 				transientProperties.put(key + PASSWORD, credentials.getPassword());
 			}
 		}
@@ -849,7 +663,7 @@ public final class TaskRepository extends PlatformObject {
 	}
 
 	public void setOffline(boolean offline) {
-		properties.put(OFFLINE, String.valueOf(offline));
+		setBooleanProperty(OFFLINE, offline);
 	}
 
 	/**
@@ -881,6 +695,10 @@ public final class TaskRepository extends PlatformObject {
 		}
 	}
 
+	private void setBooleanProperty(String key, boolean newValue) {
+		setProperty(key, Boolean.toString(newValue));
+	}
+
 	private void notifyChangeListeners(String key, String old, String value) {
 		PropertyChangeEvent event = new PropertyChangeEvent(this, key, old, value);
 		for (PropertyChangeListener listener : propertyChangeListeners) {
@@ -891,7 +709,7 @@ public final class TaskRepository extends PlatformObject {
 	public void setTimeZoneId(String timeZoneId) {
 		setProperty(IRepositoryConstants.PROPERTY_TIMEZONE, timeZoneId == null
 				? TimeZone.getDefault().getID()
-				: timeZoneId);
+						: timeZoneId);
 	}
 
 	/**
@@ -972,22 +790,22 @@ public final class TaskRepository extends PlatformObject {
 	 * @since 3.1
 	 */
 	public void setDefaultProxyEnabled(boolean useDefaultProxy) {
-		setProperty(TaskRepository.PROXY_USEDEFAULT, String.valueOf(useDefaultProxy));
+		setBooleanProperty(TaskRepository.PROXY_USEDEFAULT, useDefaultProxy);
 	}
 
 	/**
 	 * If this repository was automatically created from a template <code>value</code> should be set to true.
-	 * 
+	 *
 	 * @since 3.5
 	 * @see #isCreatedFromTemplate()
 	 */
 	public void setCreatedFromTemplate(boolean value) {
-		setProperty(TaskRepository.CREATED_FROM_TEMPLATE, String.valueOf(value));
+		setBooleanProperty(TaskRepository.CREATED_FROM_TEMPLATE, value);
 	}
 
 	/**
 	 * Returns true, if this repository was automatically created from a template.
-	 * 
+	 *
 	 * @since 3.5
 	 * @see #setCreatedFromTemplate(boolean)
 	 */
@@ -1009,4 +827,8 @@ public final class TaskRepository extends PlatformObject {
 		setProperty(IRepositoryConstants.PROPERTY_CATEGORY, category);
 	}
 
+	private ILocationService getService() {
+		return service;
+	}
+
 }
