@@ -475,13 +475,12 @@ public class SynchronizeTasksJobTest extends TestCase {
 	}
 
 	public void testGetSingleTaskDataWithRelations() throws Exception {
-		final AtomicReference<List<String>> requestedTaskIds = new AtomicReference<List<String>>();
-		requestedTaskIds.set(new ArrayList<String>());
+		final List<String> requestedTaskIds = new ArrayList<String>();
 		AbstractRepositoryConnector connector = new MockRepositoryConnectorWithTaskDataHandler() {
 			@Override
 			public TaskData getTaskData(TaskRepository taskRepository, String taskId, IProgressMonitor monitor)
 					throws CoreException {
-				requestedTaskIds.get().add(taskId);
+				requestedTaskIds.add(taskId);
 				return createTaskData(taskId);
 			}
 
@@ -503,10 +502,10 @@ public class SynchronizeTasksJobTest extends TestCase {
 		taskList.addTask(task);
 		SynchronizeTasksJob job = createSyncJob(connector, Collections.singleton(task));
 		job.run(new NullProgressMonitor());
-		assertEquals(3, requestedTaskIds.get().size());
-		assertTrue(requestedTaskIds.get().contains("1"));
-		assertTrue(requestedTaskIds.get().contains("1.sub"));
-		assertTrue(requestedTaskIds.get().contains("1.sub2"));
+		assertEquals(3, requestedTaskIds.size());
+		assertTrue(requestedTaskIds.contains("1"));
+		assertTrue(requestedTaskIds.contains("1.sub"));
+		assertTrue(requestedTaskIds.contains("1.sub2"));
 
 		ITask sub1 = taskList.getTask(MockRepositoryConnector.REPOSITORY_URL, "1.sub");
 		assertNotNull(sub1);
@@ -516,21 +515,28 @@ public class SynchronizeTasksJobTest extends TestCase {
 		assertEquals(SynchronizationState.INCOMING_NEW, ((AbstractTask) sub2).getSynchronizationState());
 
 		// same again but this time we already got them in the task list
-		requestedTaskIds.get().clear();
+		requestedTaskIds.clear();
 		job = createSyncJob(connector, Collections.singleton(task));
 		job.run(new NullProgressMonitor());
-		assertEquals(1, requestedTaskIds.get().size());
-		assertTrue(requestedTaskIds.get().contains("1"));
+		assertEquals(1, requestedTaskIds.size());
+		assertTrue(requestedTaskIds.contains("1"));
 	}
 
 	public void testGetSingleTaskDataWithRelationsAndRemoveRelation() throws Exception {
-		final AtomicReference<List<String>> requestedTaskIds = new AtomicReference<List<String>>();
-		requestedTaskIds.set(new ArrayList<String>());
+		getSingleTaskDataWithRelationsAndRemoveRelation(true);
+	}
+
+	public void testGetSingleTaskDataWithRelationsDisabled() throws Exception {
+		getSingleTaskDataWithRelationsAndRemoveRelation(false);
+	}
+
+	private void getSingleTaskDataWithRelationsAndRemoveRelation(boolean fetchSubtasks) {
+		final List<String> requestedTaskIds = new ArrayList<String>();
 		AbstractRepositoryConnector connector = new MockRepositoryConnectorWithTaskDataHandler() {
 			@Override
 			public TaskData getTaskData(TaskRepository taskRepository, String taskId, IProgressMonitor monitor)
 					throws CoreException {
-				requestedTaskIds.get().add(taskId);
+				requestedTaskIds.add(taskId);
 				return createTaskData(taskId);
 			}
 
@@ -542,42 +548,58 @@ public class SynchronizeTasksJobTest extends TestCase {
 				ArrayList<TaskRelation> relations = new ArrayList<TaskRelation>();
 				relations.add(TaskRelation.subtask("1.sub"));
 				relations.add(TaskRelation.subtask("1.sub5"));
+				relations.add(TaskRelation.subtask("taskToBecomeSubtask"));
 				return relations;
 			}
 		};
-		final ITask task = new MockTask("1");
-		final ITask subtaskToBeGone = new MockTask("1.sub2");
-		final ITask subtaskToStay = new MockTask("1.sub5");
+		ITask task = new MockTask("1");
+		ITask subtaskToBeGone = new MockTask("1.sub2");
+		ITask subtaskToStay = new MockTask("1.sub5");
+		ITask taskToBecomeSubtask = new MockTask("taskToBecomeSubtask");
+
 		taskList.addTask(task);
 		taskList.addTask(subtaskToBeGone, ((AbstractTaskContainer) task));
 		taskList.addTask(subtaskToStay, ((AbstractTaskContainer) task));
-		SynchronizeTasksJob job = createSyncJob(connector, Collections.singleton(task));
-		job.run(new NullProgressMonitor());
-		assertEquals(2, requestedTaskIds.get().size());
-		assertTrue(requestedTaskIds.get().contains("1"));
-		assertTrue(requestedTaskIds.get().contains("1.sub"));
-
-		ITask sub1 = taskList.getTask(MockRepositoryConnector.REPOSITORY_URL, "1.sub");
-		ITask sub2 = taskList.getTask(MockRepositoryConnector.REPOSITORY_URL, "1.sub2");
-		ITask sub5 = taskList.getTask(MockRepositoryConnector.REPOSITORY_URL, "1.sub5");
-		assertNotNull(sub1);
-		assertNotNull(sub2);
-		assertNotNull(sub5);
-
+		taskList.addTask(taskToBecomeSubtask);
 		Collection<ITask> children = ((AbstractTaskContainer) task).getChildren();
 		assertEquals(2, children.size());
-		assertTrue(children.contains(sub1));
-		assertTrue(children.contains(sub5));
+		assertTrue(children.contains(subtaskToBeGone));
+		assertTrue(children.contains(subtaskToStay));
+
+		SynchronizeTasksJob job = createSyncJob(connector, Collections.singleton(task));
+		job.setFetchSubtasks(fetchSubtasks);
+		job.run(new NullProgressMonitor());
+		assertEquals(fetchSubtasks ? 2 : 1, requestedTaskIds.size());
+		assertTrue(requestedTaskIds.contains("1"));
+		if (fetchSubtasks) {
+			assertTrue(requestedTaskIds.contains("1.sub"));
+		}
+
+		ITask newSubtask = taskList.getTask(MockRepositoryConnector.REPOSITORY_URL, "1.sub");
+		subtaskToBeGone = taskList.getTask(MockRepositoryConnector.REPOSITORY_URL, "1.sub2");
+		subtaskToStay = taskList.getTask(MockRepositoryConnector.REPOSITORY_URL, "1.sub5");
+		taskToBecomeSubtask = taskList.getTask(MockRepositoryConnector.REPOSITORY_URL, "taskToBecomeSubtask");
+		assertEquals(fetchSubtasks, newSubtask != null);
+		assertNotNull(subtaskToBeGone);
+		assertNotNull(subtaskToStay);
+		assertNotNull(taskToBecomeSubtask);
+
+		children = ((AbstractTaskContainer) task).getChildren();
+		assertEquals(fetchSubtasks ? 3 : 2, children.size());
+		if (fetchSubtasks) {
+			assertTrue(children.contains(newSubtask));
+		}
+		assertTrue(children.contains(subtaskToStay));
+		assertTrue(children.contains(taskToBecomeSubtask));
 	}
 
 	public void testErrorOnRelationRetrieval() throws Exception {
-		final AtomicReference<List<String>> requestedTaskIds = new AtomicReference<List<String>>();
-		requestedTaskIds.set(new ArrayList<String>());
+		final List<String> requestedTaskIds = new ArrayList<String>();
 		AbstractRepositoryConnector connector = new MockRepositoryConnectorWithTaskDataHandler() {
 			@Override
 			public TaskData getTaskData(TaskRepository taskRepository, String taskId, IProgressMonitor monitor)
 					throws CoreException {
-				requestedTaskIds.get().add(taskId);
+				requestedTaskIds.add(taskId);
 				if (taskId.equals("1.sub")) {
 					throw new CoreException(new Status(IStatus.ERROR, "bundle", "log me"));
 				}
@@ -613,13 +635,12 @@ public class SynchronizeTasksJobTest extends TestCase {
 	}
 
 	public void testTasksForSeveralRepositories() throws Exception {
-		final AtomicReference<List<String>> requestedTaskIds = new AtomicReference<List<String>>();
-		requestedTaskIds.set(new ArrayList<String>());
+		final List<String> requestedTaskIds = new ArrayList<String>();
 		AbstractRepositoryConnector connector = new MockRepositoryConnectorWithTaskDataHandler() {
 			@Override
 			public TaskData getTaskData(TaskRepository taskRepository, String taskId, IProgressMonitor monitor)
 					throws CoreException {
-				requestedTaskIds.get().add(taskId + " on " + taskRepository.getRepositoryUrl());
+				requestedTaskIds.add(taskId + " on " + taskRepository.getRepositoryUrl());
 				return createTaskData(taskId);
 			}
 
@@ -662,8 +683,8 @@ public class SynchronizeTasksJobTest extends TestCase {
 		});
 		assertEquals("beginTask|subTask|subTask|subTask|subTask|done", progressLog.toString());
 
-		assertTrue(requestedTaskIds.get().contains("1 on " + MockRepositoryConnector.REPOSITORY_URL));
-		assertTrue(requestedTaskIds.get().contains("5 on " + MockRepositoryConnector.REPOSITORY_URL + "2"));
+		assertTrue(requestedTaskIds.contains("1 on " + MockRepositoryConnector.REPOSITORY_URL));
+		assertTrue(requestedTaskIds.contains("5 on " + MockRepositoryConnector.REPOSITORY_URL + "2"));
 
 		((TaskRepositoryManager) TasksUi.getRepositoryManager()).removeRepository(secondRepository);
 		((TaskRepositoryManager) TasksUi.getRepositoryManager()).removeRepository(firstRepository);
