@@ -83,8 +83,10 @@ import org.eclipse.mylyn.internal.tasks.core.data.TaskDataManager;
 import org.eclipse.mylyn.internal.tasks.core.data.TaskDataStore;
 import org.eclipse.mylyn.internal.tasks.core.externalization.ExternalizationManager;
 import org.eclipse.mylyn.internal.tasks.core.externalization.IExternalizationParticipant;
+import org.eclipse.mylyn.internal.tasks.core.externalization.TaskActivationExternalizationParticipant;
 import org.eclipse.mylyn.internal.tasks.core.externalization.TaskListExternalizationParticipant;
 import org.eclipse.mylyn.internal.tasks.core.externalization.TaskListExternalizer;
+import org.eclipse.mylyn.internal.tasks.core.util.RepositoryConnectorLoader;
 import org.eclipse.mylyn.internal.tasks.core.util.TaskRepositoryKeyringMigrator;
 import org.eclipse.mylyn.internal.tasks.core.util.TaskRepositorySecureStoreMigrator;
 import org.eclipse.mylyn.internal.tasks.core.util.TasksCoreExtensionReader;
@@ -126,7 +128,7 @@ import org.osgi.util.tracker.ServiceTracker;
 
 /**
  * Main entry point for the Tasks UI.
- * 
+ *
  * @author Mik Kersten
  * @since 3.0
  */
@@ -280,68 +282,6 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 		}
 	};
 
-//	private static ITaskListNotificationProvider INCOMING_NOTIFICATION_PROVIDER = new ITaskListNotificationProvider() {
-//
-//		@SuppressWarnings( { "deprecation", "restriction" })
-//		public Set<AbstractNotification> getNotifications() {
-//			Set<AbstractNotification> notifications = new HashSet<AbstractNotification>();
-//			// Incoming Changes
-//			for (TaskRepository repository : getRepositoryManager().getAllRepositories()) {
-//				AbstractRepositoryConnector connector = getRepositoryManager().getRepositoryConnector(
-//						repository.getConnectorKind());
-//				if (connector instanceof AbstractLegacyRepositoryConnector) {
-//					AbstractRepositoryConnectorUi connectorUi = getConnectorUi(repository.getConnectorKind());
-//					if (connectorUi != null && !connectorUi.hasCustomNotifications()) {
-//						for (ITask itask : TasksUiPlugin.getTaskList().getTasks(repository.getRepositoryUrl())) {
-//							if (itask instanceof AbstractTask) {
-//								AbstractTask task = (AbstractTask) itask;
-//								if ((task.getLastReadTimeStamp() == null || task.getSynchronizationState() == SynchronizationState.INCOMING)
-//										&& task.isNotified() == false) {
-//									TaskListNotification notification = LegacyChangeManager.getIncommingNotification(
-//											connector, task);
-//									notifications.add(notification);
-//									task.setNotified(true);
-//								}
-//							}
-//						}
-//					}
-//				}
-//			}
-//			// New query hits
-//			for (RepositoryQuery query : TasksUiPlugin.getTaskList().getQueries()) {
-//				TaskRepository repository = getRepositoryManager().getRepository(query.getRepositoryUrl());
-//				if (repository != null) {
-//					AbstractRepositoryConnector connector = getRepositoryManager().getRepositoryConnector(
-//							repository.getConnectorKind());
-//					if (connector instanceof AbstractLegacyRepositoryConnector) {
-//						AbstractRepositoryConnectorUi connectorUi = getConnectorUi(repository.getConnectorKind());
-//						if (!connectorUi.hasCustomNotifications()) {
-//							for (ITask hit : query.getChildren()) {
-//								if (((AbstractTask) hit).isNotified() == false) {
-//									notifications.add(new TaskListNotificationQueryIncoming(hit));
-//									((AbstractTask) hit).setNotified(true);
-//								}
-//							}
-//						}
-//					}
-//				}
-//			}
-//			return notifications;
-//		}
-//	};
-
-//	private final IPropertyChangeListener PREFERENCE_LISTENER = new IPropertyChangeListener() {
-//
-//		public void propertyChange(PropertyChangeEvent event) {
-//			// TODO: do we ever get here?
-////			if (event.getProperty().equals(ContextPreferenceContstants.PREF_DATA_DIR)) {
-////				if (event.getOldValue() instanceof String) {
-////					reloadDataDirectory();
-////				}
-////			}
-//		}
-//	};
-
 	private final org.eclipse.jface.util.IPropertyChangeListener PROPERTY_LISTENER = new org.eclipse.jface.util.IPropertyChangeListener() {
 
 		public void propertyChange(org.eclipse.jface.util.PropertyChangeEvent event) {
@@ -391,6 +331,8 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 	private SynchronizationManger synchronizationManger;
 
+	private RepositoryConnectorLoader connectorLoader;
+
 	private class TasksUiInitializationJob extends UIJob {
 
 		public TasksUiInitializationJob() {
@@ -407,7 +349,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 			try {
 				// Needs to run after workbench is loaded because it
 				// relies on images.
-				TasksUiExtensionReader.initWorkbenchUiExtensions();
+				TasksUiExtensionReader.initWorkbenchUiExtensions(connectorLoader.getBlackList());
 
 				if (externalizationManager.getLoadStatus() != null) {
 					// XXX: recovery from task list load failure  (Rendered in task list)
@@ -431,7 +373,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 				// Needs to happen asynchronously to avoid bug 159706
 				for (AbstractTask task : taskList.getAllTasks()) {
 					if (task.isActive()) {
-						// the externalizer might set multiple tasks active 
+						// the externalizer might set multiple tasks active
 						task.setActive(false);
 						if (activateTask) {
 							// make sure only one task is activated
@@ -569,7 +511,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 		try {
 			// initialize framework and settings
 			if (DEBUG_HTTPCLIENT) {
-				// do this before anything else, once commons logging is initialized and an instance 
+				// do this before anything else, once commons logging is initialized and an instance
 				// of Log has been created it's too late
 				initHttpLogging();
 			}
@@ -633,7 +575,10 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 			// NOTE: initializing extensions in start(..) has caused race
 			// conditions previously
-			TasksUiExtensionReader.initStartupExtensions(taskListExternalizer, repositoryManager);
+			connectorLoader = new RepositoryConnectorLoader();
+			connectorLoader.registerConnectors(repositoryManager, taskListExternalizer);
+			connectorLoader.registerTemplates(repositoryManager, repositoryTemplateManager);
+			TasksUiExtensionReader.initStartupExtensions(connectorLoader.getBlackList());
 
 			// instantiate taskDataManager
 			TaskDataStore taskDataStore = new TaskDataStore(repositoryManager);
@@ -643,7 +588,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 			taskJobFactory = new TaskJobFactory(taskList, taskDataManager, repositoryManager, repositoryModel);
 
-			taskActivityMonitor = TasksUiExtensionReader.loadTaskActivityMonitor();
+			taskActivityMonitor = TasksCoreExtensionReader.loadTaskActivityMonitor();
 			taskActivityMonitor.start(taskActivityManager);
 
 			saveParticipant = new ISaveParticipant() {
@@ -679,7 +624,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 			migrateCredentials(repositoryManager.getAllRepositories());
 
-			// make this available early for clients that are not initialized through tasks ui but need access 
+			// make this available early for clients that are not initialized through tasks ui but need access
 			taskListNotificationManager = new TaskListNotificationManager();
 
 			String lastMod = getPreferenceStore().getString(
@@ -691,16 +636,16 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 			serviceMessageManager = new ServiceMessageManager(serviceMessageUrl, lastMod, etag, checktime,
 					new NotificationEnvironment() {
-						private Set<String> installedFeatures;
+				private Set<String> installedFeatures;
 
-						@Override
-						public Set<String> getInstalledFeatures(IProgressMonitor monitor) {
-							if (installedFeatures == null) {
-								installedFeatures = DiscoveryUi.createInstallJob().getInstalledFeatures(monitor);
-							}
-							return installedFeatures;
-						}
-					});
+				@Override
+				public Set<String> getInstalledFeatures(IProgressMonitor monitor) {
+					if (installedFeatures == null) {
+						installedFeatures = DiscoveryUi.createInstallJob().getInstalledFeatures(monitor);
+					}
+					return installedFeatures;
+				}
+			});
 
 			// Disabled for initial 3.4 release as per bug#263528
 			if (getPreferenceStore().getBoolean(ITasksUiPreferenceConstants.SERVICE_MESSAGES_ENABLED)) {
@@ -832,7 +777,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 	/**
 	 * Returns the local task repository. If the repository does not exist it is created and added to the task
 	 * repository manager.
-	 * 
+	 *
 	 * @return the local task repository; never <code>null</code>
 	 * @since 3.0
 	 */
@@ -922,7 +867,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 	 * Persist <code>path</code> as data directory and loads data from <code>path</code>. This method may block if other
 	 * jobs are running that modify tasks data. This method will only execute after all conflicting jobs have been
 	 * completed.
-	 * 
+	 *
 	 * @throws CoreException
 	 *             in case setting of the data directory did not complete normally
 	 * @throws OperationCanceledException
@@ -945,7 +890,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 						getPreferenceStore().setValue(ITasksUiPreferenceConstants.PREF_DATA_DIR, path);
 					}
 
-					// reload data from new directory				
+					// reload data from new directory
 					initializeDataSources();
 				} finally {
 					// FIXME roll back preferences change in case of an error?
@@ -1009,12 +954,12 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 			if (!taskActivityMonitor.getActivationHistory().isEmpty()) {
 				// tasks have been active before so fore preference enabled
 				MonitorUiPlugin.getDefault()
-						.getPreferenceStore()
-						.setValue(MonitorUiPlugin.ACTIVITY_TRACKING_ENABLED, true);
+				.getPreferenceStore()
+				.setValue(MonitorUiPlugin.ACTIVITY_TRACKING_ENABLED, true);
 			}
 			MonitorUiPlugin.getDefault()
-					.getPreferenceStore()
-					.setValue(MonitorUiPlugin.ACTIVITY_TRACKING_ENABLED + ".checked", true); //$NON-NLS-1$
+			.getPreferenceStore()
+			.setValue(MonitorUiPlugin.ACTIVITY_TRACKING_ENABLED + ".checked", true); //$NON-NLS-1$
 			MonitorUiPlugin.getDefault().savePluginPreferences();
 		}
 
@@ -1312,7 +1257,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 	/**
 	 * Associate a Task Repository with a workbench project
-	 * 
+	 *
 	 * @param resource
 	 *            project or resource belonging to a project
 	 * @param repository
@@ -1455,7 +1400,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 	public void initializeNotificationsAndSynchronization() {
 		// this method is invoked by the tasks ui initialization job and the task list view
-		// only proceed if both calls have been made 
+		// only proceed if both calls have been made
 		if (initializationCount.incrementAndGet() != 2) {
 			return;
 		}
