@@ -145,6 +145,9 @@ import org.eclipse.ui.statushandlers.IStatusAdapterConstants;
 import org.eclipse.ui.statushandlers.StatusAdapter;
 import org.eclipse.ui.statushandlers.StatusManager;
 
+import com.google.common.base.Strings;
+import com.google.common.collect.Ordering;
+
 /**
  * @author Steffen Pingel
  */
@@ -1195,16 +1198,55 @@ public class TasksUiInternal {
 	 * @return first task with a matching URL.
 	 */
 	public static AbstractTask getTaskByUrl(String taskUrl) {
-		Collection<AbstractTask> tasks = TasksUiPlugin.getTaskList().getAllTasks();
-		for (AbstractTask task : tasks) {
-			String currUrl = task.getUrl();
-			if (currUrl != null && !currUrl.equals("") && currUrl.equals(taskUrl)) { //$NON-NLS-1$
-				return task;
+		if (!Strings.isNullOrEmpty(taskUrl)) {
+			Collection<AbstractTask> tasks = TasksUiPlugin.getTaskList().getAllTasks();
+			List<AbstractTask> sortedTasks = sortTasksByRepositoryUrl(tasks);
+
+			AbstractRepositoryConnector connector = null;
+			TaskRepository repository = null;
+
+			for (AbstractTask task : sortedTasks) {
+				if (taskUrl.equals(task.getUrl())) {
+					return task;
+				} else {
+					String repositoryUrl = task.getRepositoryUrl();
+					if (repositoryUrl != null) {
+						if (repository == null || !repositoryUrl.equals(repository.getUrl())) {
+							connector = TasksUi.getRepositoryManager().getRepositoryConnector(task.getConnectorKind());
+							repository = getRepository(task);
+						}
+
+						if (connector != null) {
+							URL url = connector.getBrowserUrl(repository, task);
+							if (url != null && taskUrl.equals(url.toString())) {
+								return task;
+							}
+						}
+					}
+				}
 			}
 		}
 		return null;
 	}
 
+	private static List<AbstractTask> sortTasksByRepositoryUrl(Collection<AbstractTask> tasks) {
+		List<AbstractTask> sortedTasks = new Ordering<AbstractTask>() {
+
+			@Override
+			public int compare(AbstractTask left, AbstractTask right) {
+				if (left.getRepositoryUrl() == null) {
+					return 1;
+				}
+				if (right.getRepositoryUrl() == null) {
+					return -1;
+				}
+				return left.getRepositoryUrl().compareTo(right.getRepositoryUrl());
+			}
+
+		}.nullsLast().sortedCopy(tasks);
+		return sortedTasks;
+	}
+
 	public static boolean isTaskUrl(String taskUrl) {
 		Assert.isNotNull(taskUrl);
 		List<TaskRepository> repositories = TasksUiPlugin.getRepositoryManager().getAllRepositories();
