@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2013 Tasktop Technologies and others. 
+ * Copyright (c) 2004, 2013 Tasktop Technologies and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -18,8 +18,10 @@ import java.lang.reflect.InvocationTargetException;
 import java.nio.charset.Charset;
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.httpclient.URI;
@@ -51,9 +53,11 @@ import org.eclipse.mylyn.internal.tasks.core.TaskRepositoryManager;
 import org.eclipse.mylyn.internal.tasks.ui.TasksUiPlugin;
 import org.eclipse.mylyn.internal.tasks.ui.wizards.Messages;
 import org.eclipse.mylyn.tasks.core.AbstractRepositoryConnector;
+import org.eclipse.mylyn.tasks.core.RepositoryInfo;
 import org.eclipse.mylyn.tasks.core.RepositoryTemplate;
 import org.eclipse.mylyn.tasks.core.TaskRepository;
 import org.eclipse.mylyn.tasks.ui.TasksUi;
+import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.FocusAdapter;
 import org.eclipse.swt.events.FocusEvent;
@@ -86,7 +90,7 @@ import org.eclipse.ui.statushandlers.StatusManager;
 /**
  * Extend to provide custom repository settings. This page is typically invoked by the user requesting properties via
  * the Task Repositories view.
- * 
+ *
  * @author Mik Kersten
  * @author Rob Elves
  * @author Steffen Pingel
@@ -97,7 +101,7 @@ import org.eclipse.ui.statushandlers.StatusManager;
  * @since 2.0
  */
 public abstract class AbstractRepositorySettingsPage extends AbstractTaskRepositoryPage implements ITaskRepositoryPage,
-		IAdaptable {
+IAdaptable {
 
 	protected static final String PREFS_PAGE_ID_NET_PROXY = "org.eclipse.ui.net.NetPreferences"; //$NON-NLS-1$
 
@@ -186,6 +190,8 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	private boolean needsAdvanced;
 
+	private boolean needsRepositoryCredentials;
+
 	protected Composite compositeContainer;
 
 	private Composite advancedComp;
@@ -208,7 +214,15 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	private boolean needsProxy;
 
-	private Button systemProxyButton;
+	/**
+	 * @since 3.11
+	 */
+	protected Button systemProxyButton;
+
+	/**
+	 * @since 3.11
+	 */
+	protected Hyperlink changeProxySettingsLink;
 
 	private String oldProxyUsername = ""; //$NON-NLS-1$
 
@@ -248,6 +262,10 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 	 */
 	protected SectionComposite innerComposite;
 
+	private TaskRepository validatedTaskRepository;
+
+	private final Map<AuthenticationType, AuthenticationCredentials> validatedAuthenticationCredentials = new HashMap<AuthenticationType, AuthenticationCredentials>();
+
 	/**
 	 * @since 3.10
 	 */
@@ -263,6 +281,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 			throw new IllegalArgumentException(
 					"connectorKind of repository does not match connectorKind of page, expected '" + getConnectorKind() + "', got '" + repository.getConnectorKind() + "'"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 		}
+		setNeedsRepositoryCredentials(true);
 		setNeedsAnonymousLogin(false);
 		setNeedsEncoding(true);
 		setNeedsTimeZone(true);
@@ -317,19 +336,23 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 		}
 		Point p = innerComposite.getContent().computeSize(SWT.DEFAULT, SWT.DEFAULT, true);
 		innerComposite.setMinSize(p);
-		swapUserNameWithAnonymousInTabList();
+		if (needsRepositoryCredentials()) {
+			swapUserNameWithAnonymousInTabList();
+		}
 		Dialog.applyDialogFont(innerComposite);
 		setControl(innerComposite);
 	}
 
 	private void swapUserNameWithAnonymousInTabList() {
-		List<Control> tabList = Arrays.asList(compositeContainer.getTabList());
-		if (tabList.contains(repositoryUserNameEditor.getTextControl(compositeContainer))
-				&& tabList.contains(anonymousButton)) {
-			int userNameIndex = tabList.indexOf(repositoryUserNameEditor.getTextControl(compositeContainer));
-			int anonymousIndex = tabList.indexOf(anonymousButton);
-			Collections.swap(tabList, userNameIndex, anonymousIndex);
-			compositeContainer.setTabList(tabList.toArray(new Control[tabList.size()]));
+		if (compositeContainer != null && anonymousButton != null && repositoryUserNameEditor != null) {
+			List<Control> tabList = Arrays.asList(compositeContainer.getTabList());
+			if (tabList.contains(repositoryUserNameEditor.getTextControl(compositeContainer))
+					&& tabList.contains(anonymousButton)) {
+				int userNameIndex = tabList.indexOf(repositoryUserNameEditor.getTextControl(compositeContainer));
+				int anonymousIndex = tabList.indexOf(anonymousButton);
+				Collections.swap(tabList, userNameIndex, anonymousIndex);
+				compositeContainer.setTabList(tabList.toArray(new Control[tabList.size()]));
+			}
 		}
 	}
 
@@ -398,10 +421,10 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 		});
 
 		GridDataFactory.fillDefaults()
-				.hint(300, SWT.DEFAULT)
-				.grab(true, false)
-				.span(2, SWT.DEFAULT)
-				.applyTo(serverUrlCombo);
+		.hint(300, SWT.DEFAULT)
+		.grab(true, false)
+		.span(2, SWT.DEFAULT)
+		.applyTo(serverUrlCombo);
 
 		repositoryLabelEditor = new StringFieldEditor("", LABEL_REPOSITORY_LABEL, StringFieldEditor.UNLIMITED, //$NON-NLS-1$
 				compositeContainer) {
@@ -439,6 +462,98 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 			}
 		});
 
+		if (needsRepositoryCredentials()) {
+			createRepositoryCredentialsSection();
+		}
+
+		if (needsAdvanced() || needsEncoding()) {
+			createAdvancedSection();
+		}
+
+		if (needsCertAuth()) {
+			createCertAuthSection();
+		}
+
+		if (needsHttpAuth()) {
+			createHttpAuthSection();
+		}
+
+		if (needsProxy()) {
+			createProxySection();
+		}
+
+		createContributionControls(innerComposite);
+
+		Composite managementComposite = new Composite(compositeContainer, SWT.NULL);
+		GridLayout managementLayout = new GridLayout(4, false);
+		managementLayout.marginHeight = 0;
+		managementLayout.marginWidth = 0;
+		managementLayout.horizontalSpacing = 10;
+		managementComposite.setLayout(managementLayout);
+		managementComposite.setLayoutData(new GridData(SWT.LEFT, SWT.TOP, false, false, 2, 1));
+
+		createAccountHyperlink = toolkit.createHyperlink(managementComposite,
+				Messages.AbstractRepositorySettingsPage_Create_new_account, SWT.NONE);
+		createAccountHyperlink.setBackground(managementComposite.getBackground());
+		createAccountHyperlink.addHyperlinkListener(new HyperlinkAdapter() {
+			@Override
+			public void linkActivated(HyperlinkEvent e) {
+//				TaskRepository repository = getRepository();
+				TaskRepository repository = createTaskRepository();
+//				if (repository == null && getServerUrl() != null && getServerUrl().length() > 0) {
+//					repository = createTaskRepository();
+//				}
+				if (repository != null) {
+					String accountCreationUrl = TasksUiPlugin.getConnectorUi(connector.getConnectorKind())
+							.getAccountCreationUrl(repository);
+					if (accountCreationUrl != null) {
+						BrowserUtil.openUrl(accountCreationUrl, IWorkbenchBrowserSupport.AS_EXTERNAL);
+					}
+				}
+			}
+		});
+
+		manageAccountHyperlink = toolkit.createHyperlink(managementComposite,
+				Messages.AbstractRepositorySettingsPage_Change_account_settings, SWT.NONE);
+		manageAccountHyperlink.setBackground(managementComposite.getBackground());
+		manageAccountHyperlink.addHyperlinkListener(new HyperlinkAdapter() {
+			@Override
+			public void linkActivated(HyperlinkEvent e) {
+				TaskRepository repository = getRepository();
+				if (repository == null && getRepositoryUrl() != null && getRepositoryUrl().length() > 0) {
+					repository = createTaskRepository();
+				}
+				if (repository != null) {
+					String accountManagementUrl = TasksUiPlugin.getConnectorUi(connector.getConnectorKind())
+							.getAccountManagementUrl(repository);
+					if (accountManagementUrl != null) {
+						BrowserUtil.openUrl(accountManagementUrl, IWorkbenchBrowserSupport.AS_EXTERNAL);
+					}
+				}
+			}
+		});
+
+		if (needsRepositoryCredentials()) {
+			// bug 131656: must set echo char after setting value on Mac
+			((RepositoryStringFieldEditor) repositoryPasswordEditor).getTextControl().setEchoChar('*');
+
+			if (needsAnonymousLogin()) {
+				// do this after username and password widgets have been intialized
+				if (repository != null) {
+					setAnonymous(isAnonymousAccess());
+				}
+			}
+		}
+
+		updateHyperlinks();
+		if (repository != null) {
+			saveToValidatedProperties(createTaskRepository());
+		}
+		GridLayout layout = new GridLayout(3, false);
+		compositeContainer.setLayout(layout);
+	}
+
+	private void createRepositoryCredentialsSection() {
 		repositoryUserNameEditor = new StringFieldEditor("", LABEL_USER, StringFieldEditor.UNLIMITED, //$NON-NLS-1$
 				compositeContainer) {
 
@@ -551,110 +666,6 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 		} else {
 			savePasswordButton.setSelection(false);
 		}
-
-		// TODO: put this back if we can't get the info from all connectors
-		// if (needsTimeZone()) {
-		// Label timeZoneLabel = new Label(container, SWT.NONE);
-		// timeZoneLabel.setText("Repository time zone: ");
-		// timeZonesCombo = new Combo(container, SWT.READ_ONLY);
-		// String[] timeZoneIds = TimeZone.getAvailableIDs();
-		// Arrays.sort(timeZoneIds);
-		// for (String zone : timeZoneIds) {
-		// timeZonesCombo.add(zone);
-		// }
-		// boolean setZone = false;
-		// if (repository != null) {
-		// if (timeZonesCombo.indexOf(repository.getTimeZoneId()) > -1) {
-		// timeZonesCombo.select(timeZonesCombo.indexOf(repository.getTimeZoneId()));
-		// setZone = true;
-		// }
-		// }
-		// if (!setZone) {
-		// timeZonesCombo.select(timeZonesCombo.indexOf(TimeZone.getDefault().getID()));
-		// }
-		// }
-
-		if (needsAdvanced() || needsEncoding()) {
-			createAdvancedSection();
-		}
-
-		if (needsCertAuth()) {
-			createCertAuthSection();
-		}
-
-		if (needsHttpAuth()) {
-			createHttpAuthSection();
-		}
-
-		if (needsProxy()) {
-			createProxySection();
-		}
-
-		createContributionControls(innerComposite);
-
-		Composite managementComposite = new Composite(compositeContainer, SWT.NULL);
-		GridLayout managementLayout = new GridLayout(4, false);
-		managementLayout.marginHeight = 0;
-		managementLayout.marginWidth = 0;
-		managementLayout.horizontalSpacing = 10;
-		managementComposite.setLayout(managementLayout);
-		managementComposite.setLayoutData(new GridData(SWT.LEFT, SWT.TOP, false, false, 2, 1));
-
-		createAccountHyperlink = toolkit.createHyperlink(managementComposite,
-				Messages.AbstractRepositorySettingsPage_Create_new_account, SWT.NONE);
-		createAccountHyperlink.setBackground(managementComposite.getBackground());
-		createAccountHyperlink.addHyperlinkListener(new HyperlinkAdapter() {
-			@Override
-			public void linkActivated(HyperlinkEvent e) {
-//				TaskRepository repository = getRepository();
-				TaskRepository repository = createTaskRepository();
-//				if (repository == null && getServerUrl() != null && getServerUrl().length() > 0) {
-//					repository = createTaskRepository();
-//				}
-				if (repository != null) {
-					String accountCreationUrl = TasksUiPlugin.getConnectorUi(connector.getConnectorKind())
-							.getAccountCreationUrl(repository);
-					if (accountCreationUrl != null) {
-						BrowserUtil.openUrl(accountCreationUrl, IWorkbenchBrowserSupport.AS_EXTERNAL);
-					}
-				}
-			}
-		});
-
-		manageAccountHyperlink = toolkit.createHyperlink(managementComposite,
-				Messages.AbstractRepositorySettingsPage_Change_account_settings, SWT.NONE);
-		manageAccountHyperlink.setBackground(managementComposite.getBackground());
-		manageAccountHyperlink.addHyperlinkListener(new HyperlinkAdapter() {
-			@Override
-			public void linkActivated(HyperlinkEvent e) {
-				TaskRepository repository = getRepository();
-				if (repository == null && getRepositoryUrl() != null && getRepositoryUrl().length() > 0) {
-					repository = createTaskRepository();
-				}
-				if (repository != null) {
-					String accountManagementUrl = TasksUiPlugin.getConnectorUi(connector.getConnectorKind())
-							.getAccountManagementUrl(repository);
-					if (accountManagementUrl != null) {
-						BrowserUtil.openUrl(accountManagementUrl, IWorkbenchBrowserSupport.AS_EXTERNAL);
-					}
-				}
-			}
-		});
-
-		// bug 131656: must set echo char after setting value on Mac
-		((RepositoryStringFieldEditor) repositoryPasswordEditor).getTextControl().setEchoChar('*');
-
-		if (needsAnonymousLogin()) {
-			// do this after username and password widgets have been intialized
-			if (repository != null) {
-				setAnonymous(isAnonymousAccess());
-			}
-		}
-
-		updateHyperlinks();
-
-		GridLayout layout = new GridLayout(3, false);
-		compositeContainer.setLayout(layout);
 	}
 
 	private void createAdvancedSection() {
@@ -701,7 +712,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 			} catch (LinkageError e) {
 				StatusHandler.log(new Status(IStatus.ERROR, TasksUiPlugin.ID_PLUGIN,
 						Messages.AbstractRepositorySettingsPage_Problems_encountered_determining_available_charsets, e));
-				// bug 237972: 3rd party encodings can cause availableCharsets() to fail 
+				// bug 237972: 3rd party encodings can cause availableCharsets() to fail
 				otherEncoding.setEnabled(false);
 				otherEncodingCombo.setEnabled(false);
 			}
@@ -755,10 +766,10 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 		certAuthButton = new Button(certAuthComp, SWT.CHECK);
 		GridDataFactory.fillDefaults()
-				.indent(0, 5)
-				.align(SWT.LEFT, SWT.TOP)
-				.span(3, SWT.DEFAULT)
-				.applyTo(certAuthButton);
+		.indent(0, 5)
+		.align(SWT.LEFT, SWT.TOP)
+		.span(3, SWT.DEFAULT)
+		.applyTo(certAuthButton);
 
 		certAuthButton.setText(Messages.AbstractRepositorySettingsPage_Enable_certificate_authentification);
 
@@ -850,10 +861,10 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 		httpAuthButton = new Button(httpAuthComp, SWT.CHECK);
 		GridDataFactory.fillDefaults()
-				.indent(0, 5)
-				.align(SWT.LEFT, SWT.TOP)
-				.span(3, SWT.DEFAULT)
-				.applyTo(httpAuthButton);
+		.indent(0, 5)
+		.align(SWT.LEFT, SWT.TOP)
+		.span(3, SWT.DEFAULT)
+		.applyTo(httpAuthButton);
 
 		httpAuthButton.setText(Messages.AbstractRepositorySettingsPage_Enable_http_authentication);
 
@@ -1012,7 +1023,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 			}
 		});
 
-		Hyperlink changeProxySettingsLink = toolkit.createHyperlink(systemSettingsComposite,
+		changeProxySettingsLink = toolkit.createHyperlink(systemSettingsComposite,
 				Messages.AbstractRepositorySettingsPage_Change_Settings, SWT.NULL);
 		changeProxySettingsLink.setBackground(compositeContainer.getBackground());
 		changeProxySettingsLink.addHyperlinkListener(new IHyperlinkListener() {
@@ -1060,6 +1071,19 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 				"", Messages.AbstractRepositorySettingsPage_Proxy_host_port_, StringFieldEditor.UNLIMITED, //$NON-NLS-1$
 				proxyAuthComp) {
 
+			@Override
+			protected boolean doCheckState() {
+				return true;
+			}
+
+			@Override
+			protected void valueChanged() {
+				super.valueChanged();
+				if (getWizard() != null) {
+					getWizard().getContainer().updateButtons();
+				}
+			}
+
 			@Override
 			public int getNumberOfControls() {
 				return 3;
@@ -1578,8 +1602,8 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 			if (!isValidUrl(url)) {
 				errorMessage = Messages.AbstractRepositorySettingsPage_Enter_a_valid_server_url;
 			}
-			if (errorMessage == null && (!needsAnonymousLogin() || !anonymousButton.getSelection())
-					&& isMissingCredentials()) {
+			if (errorMessage == null && needsRepositoryCredentials()
+					&& (!needsAnonymousLogin() || !anonymousButton.getSelection()) && isMissingCredentials()) {
 				errorMessage = Messages.AbstractRepositorySettingsPage_Enter_a_user_id_Message0;
 			}
 			setMessage(errorMessage, repository == null ? IMessageProvider.NONE : IMessageProvider.ERROR);
@@ -1591,11 +1615,11 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	/**
 	 * Returns true, if credentials are incomplete. Clients may override this method.
-	 * 
+	 *
 	 * @since 3.4
 	 */
 	protected boolean isMissingCredentials() {
-		return repositoryUserNameEditor.getStringValue().trim().equals("") //$NON-NLS-1$
+		return needsRepositoryCredentials() && repositoryUserNameEditor.getStringValue().trim().equals("") //$NON-NLS-1$
 				|| (getSavePassword() && repositoryPasswordEditor.getStringValue().trim().equals("")); //$NON-NLS-1$
 	}
 
@@ -1677,7 +1701,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 	 * Note: The credentials of the created repository are not persisted in the platform keystore. When overriding,
 	 * subclasses must either call super or call {@link TaskRepository#setShouldPersistCredentials(boolean)
 	 * setShouldPersistCredentials(false)} before calling {@link #applyTo(TaskRepository)}.
-	 * 
+	 *
 	 * @since 2.0
 	 */
 	public TaskRepository createTaskRepository() {
@@ -1693,16 +1717,22 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 	 */
 	@Override
 	public void applyTo(@NonNull TaskRepository repository) {
+		String category = repository.getCategory();
+		if (category == null || category.length() == 0) {
+			connector.applyDefaultCategory(repository);
+		}
 		repository.setVersion(getVersion());
 		if (needsEncoding()) {
 			repository.setCharacterEncoding(getCharacterEncoding());
 		}
 
-		if (isAnonymousAccess()) {
-			repository.setCredentials(AuthenticationType.REPOSITORY, null, getSavePassword());
-		} else {
-			AuthenticationCredentials credentials = new AuthenticationCredentials(getUserName(), getPassword());
-			repository.setCredentials(AuthenticationType.REPOSITORY, credentials, getSavePassword());
+		if (needsRepositoryCredentials()) {
+			if (isAnonymousAccess()) {
+				repository.setCredentials(AuthenticationType.REPOSITORY, null, getSavePassword());
+			} else {
+				AuthenticationCredentials credentials = new AuthenticationCredentials(getUserName(), getPassword());
+				repository.setCredentials(AuthenticationType.REPOSITORY, credentials, getSavePassword());
+			}
 		}
 		repository.setRepositoryLabel(getRepositoryLabel());
 
@@ -1774,6 +1804,13 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 		return needsAnonymousLogin;
 	}
 
+	/**
+	 * @since 3.11
+	 */
+	public boolean needsRepositoryCredentials() {
+		return needsRepositoryCredentials;
+	}
+
 	/**
 	 * @since 2.0
 	 */
@@ -1851,6 +1888,13 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 		this.needsAnonymousLogin = needsAnonymousLogin;
 	}
 
+	/**
+	 * @since 3.11
+	 */
+	public void setNeedsRepositoryCredentials(boolean needsRepositoryCredentials) {
+		this.needsRepositoryCredentials = needsRepositoryCredentials;
+	}
+
 	public void setNeedsValidation(boolean needsValidation) {
 		this.needsValidation = needsValidation;
 	}
@@ -1860,7 +1904,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 	 * <p>
 	 * This information is typically used by the wizard to set the enablement of the validation UI affordance.
 	 * </p>
-	 * 
+	 *
 	 * @return <code>true</code> if this page can be validated, and <code>false</code> otherwise
 	 * @see #needsValidation()
 	 * @see IWizardContainer#updateButtons()
@@ -1879,7 +1923,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	/**
 	 * Public for testing.
-	 * 
+	 *
 	 * @since 2.0
 	 */
 	public void setUrl(String url) {
@@ -1888,7 +1932,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	/**
 	 * Public for testing.
-	 * 
+	 *
 	 * @since 2.0
 	 */
 	public void setUserId(String id) {
@@ -1897,7 +1941,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	/**
 	 * Public for testing.
-	 * 
+	 *
 	 * @since 2.0
 	 */
 	public void setPassword(String pass) {
@@ -1946,11 +1990,12 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	/**
 	 * Validate settings provided by the {@link #getValidator(TaskRepository) validator}, typically the server settings.
-	 * 
+	 *
 	 * @since 2.0
 	 */
 	protected void validateSettings() {
-		final Validator validator = getValidator(createTaskRepository());
+		TaskRepository newTaskRepository = createTaskRepository();
+		final Validator validator = getValidator(newTaskRepository);
 		if (validator == null) {
 			return;
 		}
@@ -1981,7 +2026,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 			StatusManager.getManager().handle(
 					new Status(IStatus.ERROR, TasksUiPlugin.ID_PLUGIN,
 							Messages.AbstractRepositorySettingsPage_Internal_error_validating_repository, e),
-					StatusManager.SHOW | StatusManager.LOG);
+							StatusManager.SHOW | StatusManager.LOG);
 			return;
 		} catch (InterruptedException e) {
 			// canceled
@@ -1990,6 +2035,9 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 		getWizard().getContainer().updateButtons();
 		applyValidatorResult(validator);
+		if (isValid) {
+			saveToValidatedProperties(newTaskRepository);
+		}
 	}
 
 	/**
@@ -2036,13 +2084,28 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 	}
 
 	/**
+	 * For version 3.11 we change the abstract implementation to a default implementation. The default implementation
+	 * creates an {@link Validator} and deligate the work to
+	 * {@link AbstractRepositoryConnector#validateRepository(TaskRepository, IProgressMonitor)}
+	 *
 	 * @since 2.0
 	 */
-	protected abstract Validator getValidator(@NonNull TaskRepository repository);
+
+	protected Validator getValidator(@NonNull final TaskRepository repository) {
+		return new org.eclipse.mylyn.tasks.ui.wizards.AbstractRepositorySettingsPage.Validator() {
+
+			@Override
+			public void run(IProgressMonitor monitor) throws CoreException {
+				RepositoryInfo repositoryInfo = connector.validateRepository(repository, monitor);
+				setStatus(new Status(IStatus.OK, TasksUiPlugin.ID_PLUGIN, NLS.bind(
+						Messages.AbstractRepositorySettingsPage_Settings_are_valid_version, repositoryInfo.getVersion())));
+			}
+		};
+	}
 
 	/**
 	 * Public for testing.
-	 * 
+	 *
 	 * @since 2.0
 	 */
 	public abstract class Validator {
@@ -2063,7 +2126,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	/**
 	 * Provides an adapter for the {@link IValidatable} interface.
-	 * 
+	 *
 	 * @since 3.7
 	 * @see IAdaptable#getAdapter(Class)
 	 */
@@ -2102,7 +2165,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	@Override
 	public boolean preFinish(TaskRepository repository) {
-		if (validateOnFinishButton != null && validateOnFinishButton.getSelection()) {
+		if (validateOnFinishButton != null && validateOnFinishButton.getSelection() && !propertiesUnchanged()) {
 			isValid = false;
 			validateSettings();
 		} else {
@@ -2125,7 +2188,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	/**
 	 * Returns the toolkit used to construct sections and hyperlinks.
-	 * 
+	 *
 	 * @return the toolkit
 	 * @throws IllegalStateException
 	 *             if the toolkit has not been initialized
@@ -2138,4 +2201,37 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 		return toolkit;
 	}
 
+	private boolean propertiesUnchanged() {
+		TaskRepository newRepository = createTaskRepository();
+		boolean propertiesUnchanged = false;
+		if (validatedTaskRepository != null) {
+			propertiesUnchanged = validatedTaskRepository.getProperties().equals(newRepository.getProperties());
+			if (propertiesUnchanged) {
+				for (AuthenticationType authenticationType : AuthenticationType.values()) {
+					AuthenticationCredentials credentialsOld = validatedAuthenticationCredentials.get(authenticationType);
+					AuthenticationCredentials credentialsNew = newRepository.getCredentials(authenticationType);
+					if (credentialsOld != null) {
+						propertiesUnchanged = credentialsOld.equals(credentialsNew);
+						if (!propertiesUnchanged) {
+							break;
+						}
+					} else if (credentialsNew != null) {
+						propertiesUnchanged = false;
+						break;
+					}
+				}
+			}
+		}
+		return propertiesUnchanged;
+	}
+
+	private void saveToValidatedProperties(TaskRepository taskRepository) {
+		validatedTaskRepository = taskRepository;
+		validatedAuthenticationCredentials.clear();
+		for (AuthenticationType authenticationType : AuthenticationType.values()) {
+			AuthenticationCredentials ra = validatedTaskRepository.getCredentials(authenticationType);
+			validatedAuthenticationCredentials.put(authenticationType, ra);
+		}
+	}
+
 }
